@@ -63,9 +63,6 @@ import org.apache.commons.configuration2.ex.ConfigurationRuntimeException;
  * children.
  * </p>
  *
- * @author <a href="mailto:epugh@upstate.com">Eric Pugh</a>
- * @author <a href="mailto:hps@intermeta.de">Henning P. Schmiedehausen</a>
- * @version $Id: CompositeConfiguration.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class CompositeConfiguration extends AbstractConfiguration
 implements Cloneable
@@ -106,7 +103,7 @@ implements Cloneable
      *
      * @param inMemoryConfiguration the in memory configuration to use
      */
-    public CompositeConfiguration(Configuration inMemoryConfiguration)
+    public CompositeConfiguration(final Configuration inMemoryConfiguration)
     {
         configList.clear();
         this.inMemoryConfiguration = inMemoryConfiguration;
@@ -119,7 +116,7 @@ implements Cloneable
      *
      * @param configurations the collection of configurations to add
      */
-    public CompositeConfiguration(Collection<? extends Configuration> configurations)
+    public CompositeConfiguration(final Collection<? extends Configuration> configurations)
     {
         this(new BaseConfiguration(), configurations);
     }
@@ -132,14 +129,14 @@ implements Cloneable
      * @param configurations        the collection of configurations to add
      * @see #CompositeConfiguration(Configuration)
      */
-    public CompositeConfiguration(Configuration inMemoryConfiguration,
-            Collection<? extends Configuration> configurations)
+    public CompositeConfiguration(final Configuration inMemoryConfiguration,
+            final Collection<? extends Configuration> configurations)
     {
         this(inMemoryConfiguration);
 
         if (configurations != null)
         {
-            for (Configuration c : configurations)
+            for (final Configuration c : configurations)
             {
                 addConfiguration(c);
             }
@@ -151,7 +148,7 @@ implements Cloneable
      *
      * @param config the configuration to add
      */
-    public void addConfiguration(Configuration config)
+    public void addConfiguration(final Configuration config)
     {
         addConfiguration(config, false);
     }
@@ -171,7 +168,7 @@ implements Cloneable
      *        <em>in-memory</em> configuration, <b>false</b> otherwise
      * @since 1.8
      */
-    public void addConfiguration(Configuration config, boolean asInMemory)
+    public void addConfiguration(final Configuration config, final boolean asInMemory)
     {
         beginWrite(false);
         try
@@ -213,12 +210,64 @@ implements Cloneable
         }
     }
 
+    /**
+     * Add a configuration to the start of the list of child configurations.
+     *
+     * @param config the configuration to add
+     * @since 2.3
+     */
+    public void addConfigurationFirst(final Configuration config)
+    {
+        addConfigurationFirst(config, false);
+    }
+
+    /**
+     * Adds a child configuration to the start of the collection and optionally
+     * makes it the <em>in-memory configuration</em>. This means that all future
+     * property write operations are executed on this configuration. Note that
+     * the current in-memory configuration is replaced by the new one. If it was
+     * created automatically or passed to the constructor, it is removed from the
+     * list of child configurations! Otherwise, it stays in the list of child configurations
+     * at its current position, but it passes its role as in-memory configuration to the new one.
+     *
+     * @param config the configuration to be added
+     * @param asInMemory <b>true</b> if this configuration becomes the new
+     *        <em>in-memory</em> configuration, <b>false</b> otherwise
+     * @since 2.3
+     */
+    public void addConfigurationFirst(final Configuration config, final boolean asInMemory)
+    {
+        beginWrite(false);
+        try
+        {
+            if (!configList.contains(config))
+            {
+                if (asInMemory)
+                {
+                    replaceInMemoryConfiguration(config);
+                    inMemoryConfigIsChild = true;
+                }
+                configList.add(0, config);
+
+                if (config instanceof AbstractConfiguration)
+                {
+                    ((AbstractConfiguration) config)
+                            .setThrowExceptionOnMissing(isThrowExceptionOnMissing());
+                }
+            }
+        }
+        finally
+        {
+            endWrite();
+        }
+    }
+
     /**
      * Remove a configuration. The in memory configuration cannot be removed.
      *
      * @param config The configuration to remove
      */
-    public void removeConfiguration(Configuration config)
+    public void removeConfiguration(final Configuration config)
     {
         beginWrite(false);
         try
@@ -278,7 +327,7 @@ implements Cloneable
      * @param token The Value to add.
      */
     @Override
-    protected void addPropertyDirect(String key, Object token)
+    protected void addPropertyDirect(final String key, final Object token)
     {
         inMemoryConfiguration.addProperty(key, token);
     }
@@ -291,10 +340,10 @@ implements Cloneable
      * @return object associated with the given configuration key.
      */
     @Override
-    protected Object getPropertyInternal(String key)
+    protected Object getPropertyInternal(final String key)
     {
         Configuration firstMatchingConfiguration = null;
-        for (Configuration config : configList)
+        for (final Configuration config : configList)
         {
             if (config.containsKey(key))
             {
@@ -307,19 +356,16 @@ implements Cloneable
         {
             return firstMatchingConfiguration.getProperty(key);
         }
-        else
-        {
-            return null;
-        }
+        return null;
     }
 
     @Override
     protected Iterator<String> getKeysInternal()
     {
-        Set<String> keys = new LinkedHashSet<>();
-        for (Configuration config : configList)
+        final Set<String> keys = new LinkedHashSet<>();
+        for (final Configuration config : configList)
         {
-            for (Iterator<String> it = config.getKeys(); it.hasNext();)
+            for (final Iterator<String> it = config.getKeys(); it.hasNext();)
             {
                 keys.add(it.next());
             }
@@ -329,12 +375,12 @@ implements Cloneable
     }
 
     @Override
-    protected Iterator<String> getKeysInternal(String key)
+    protected Iterator<String> getKeysInternal(final String key)
     {
-        Set<String> keys = new LinkedHashSet<>();
-        for (Configuration config : configList)
+        final Set<String> keys = new LinkedHashSet<>();
+        for (final Configuration config : configList)
         {
-            for (Iterator<String> it = config.getKeys(key); it.hasNext();)
+            for (final Iterator<String> it = config.getKeys(key); it.hasNext();)
             {
                 keys.add(it.next());
             }
@@ -346,7 +392,7 @@ implements Cloneable
     @Override
     protected boolean isEmptyInternal()
     {
-        for (Configuration config : configList)
+        for (final Configuration config : configList)
         {
             if (!config.isEmpty())
             {
@@ -358,18 +404,18 @@ implements Cloneable
     }
 
     @Override
-    protected void clearPropertyDirect(String key)
+    protected void clearPropertyDirect(final String key)
     {
-        for (Configuration config : configList)
+        for (final Configuration config : configList)
         {
             config.clearProperty(key);
         }
     }
 
     @Override
-    protected boolean containsKeyInternal(String key)
+    protected boolean containsKeyInternal(final String key)
     {
-        for (Configuration config : configList)
+        for (final Configuration config : configList)
         {
             if (config.containsKey(key))
             {
@@ -380,15 +426,15 @@ implements Cloneable
     }
 
     @Override
-    public List<Object> getList(String key, List<?> defaultValue)
+    public List<Object> getList(final String key, final List<?> defaultValue)
     {
-        List<Object> list = new ArrayList<>();
+        final List<Object> list = new ArrayList<>();
 
         // add all elements from the first configuration containing the requested key
-        Iterator<Configuration> it = configList.iterator();
+        final Iterator<Configuration> it = configList.iterator();
         while (it.hasNext() && list.isEmpty())
         {
-            Configuration config = it.next();
+            final Configuration config = it.next();
             if (config != inMemoryConfiguration && config.containsKey(key))
             {
                 appendListProperty(list, config, key);
@@ -402,11 +448,12 @@ implements Cloneable
         {
             // This is okay because we just return this list to the caller
             @SuppressWarnings("unchecked")
+            final
             List<Object> resultList = (List<Object>) defaultValue;
             return resultList;
         }
 
-        ListIterator<Object> lit = list.listIterator();
+        final ListIterator<Object> lit = list.listIterator();
         while (lit.hasNext())
         {
             lit.set(interpolate(lit.next()));
@@ -416,12 +463,12 @@ implements Cloneable
     }
 
     @Override
-    public String[] getStringArray(String key)
+    public String[] getStringArray(final String key)
     {
-        List<Object> list = getList(key);
+        final List<Object> list = getList(key);
 
         // transform property values into strings
-        String[] tokens = new String[list.size()];
+        final String[] tokens = new String[list.size()];
 
         for (int i = 0; i < tokens.length; i++)
         {
@@ -437,7 +484,7 @@ implements Cloneable
      * @param index The index of the configuration to retrieve
      * @return the configuration at this index
      */
-    public Configuration getConfiguration(int index)
+    public Configuration getConfiguration(final int index)
     {
         beginRead(false);
         try
@@ -484,14 +531,14 @@ implements Cloneable
     {
         try
         {
-            CompositeConfiguration copy = (CompositeConfiguration) super
+            final CompositeConfiguration copy = (CompositeConfiguration) super
                     .clone();
             copy.configList = new LinkedList<>();
             copy.inMemoryConfiguration = ConfigurationUtils
                     .cloneConfiguration(getInMemoryConfiguration());
             copy.configList.add(copy.inMemoryConfiguration);
 
-            for (Configuration config : configList)
+            for (final Configuration config : configList)
             {
                 if (config != getInMemoryConfiguration())
                 {
@@ -503,7 +550,7 @@ implements Cloneable
             copy.cloneInterpolator(this);
             return copy;
         }
-        catch (CloneNotSupportedException cnex)
+        catch (final CloneNotSupportedException cnex)
         {
             // cannot happen
             throw new ConfigurationRuntimeException(cnex);
@@ -516,7 +563,7 @@ implements Cloneable
      */
     @Override
     public void setListDelimiterHandler(
-            ListDelimiterHandler listDelimiterHandler)
+            final ListDelimiterHandler listDelimiterHandler)
     {
         if (inMemoryConfiguration instanceof AbstractConfiguration)
         {
@@ -549,7 +596,7 @@ implements Cloneable
      * determined
      * @since 1.5
      */
-    public Configuration getSource(String key)
+    public Configuration getSource(final String key)
     {
         if (key == null)
         {
@@ -557,7 +604,7 @@ implements Cloneable
         }
 
         Configuration source = null;
-        for (Configuration conf : configList)
+        for (final Configuration conf : configList)
         {
             if (conf.containsKey(key))
             {
@@ -578,7 +625,7 @@ implements Cloneable
      *
      * @param config the new in-memory configuration
      */
-    private void replaceInMemoryConfiguration(Configuration config)
+    private void replaceInMemoryConfiguration(final Configuration config)
     {
         if (!inMemoryConfigIsChild)
         {
@@ -597,15 +644,15 @@ implements Cloneable
      * @param config the configuration to query
      * @param key the key of the property
      */
-    private  void appendListProperty(List<Object> dest, Configuration config,
-            String key)
+    private  void appendListProperty(final List<Object> dest, final Configuration config,
+            final String key)
     {
-        Object value = interpolate(config.getProperty(key));
+        final Object value = interpolate(config.getProperty(key));
         if (value != null)
         {
             if (value instanceof Collection)
             {
-                Collection<?> col = (Collection<?>) value;
+                final Collection<?> col = (Collection<?>) value;
                 dest.addAll(col);
             }
             else
