@@ -209,7 +209,7 @@ import org.apache.commons.configuration2.tree.TrackedNodeModel;
  * As this class extends {@link AbstractConfiguration}, all basic features
  * like variable interpolation, list handling, or data type conversions are
  * available as well. This is described in the chapter
- * <a href="http://commons.apache.org/proper/commons-configuration/userguide/howto_basicfeatures.html">
+ * <a href="https://commons.apache.org/proper/commons-configuration/userguide/howto_basicfeatures.html">
  * Basic features and AbstractConfiguration</a> of the user's guide.
  * </p>
  * <p>
@@ -217,22 +217,18 @@ import org.apache.commons.configuration2.tree.TrackedNodeModel;
  * Such properties are considered to be section nodes.
  * </p>
  *
- * @author <a
- *         href="http://commons.apache.org/configuration/team-list.html">Commons
- *         Configuration team</a>
- * @version $Id: INIConfiguration.java 1806819 2017-08-31 16:03:06Z oheger $
  * @since 1.6
  */
 public class INIConfiguration extends BaseHierarchicalConfiguration implements
         FileBasedConfiguration
 {
     /**
-     * The characters that signal the start of a comment line.
+     * The default characters that signal the start of a comment line.
      */
     protected static final String COMMENT_CHARS = "#;";
 
     /**
-     * The characters used to separate keys from values.
+     * The default characters used to separate keys from values.
      */
     protected static final String SEPARATOR_CHARS = "=:";
 
@@ -256,6 +252,17 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      */
     private String separatorUsedInOutput = " = ";
 
+    /**
+     * The separator used when reading an INI file.
+     */
+    private String separatorUsedInInput = SEPARATOR_CHARS;
+
+    /**
+     * The characters used to separate keys from values
+     * when reading an INI file.
+     */
+    private String commentCharsUsedInInput = COMMENT_CHARS;
+
     /**
      * Create a new empty INI Configuration.
      */
@@ -271,7 +278,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param c the configuration to be copied
      * @since 2.0
      */
-    public INIConfiguration(HierarchicalConfiguration<ImmutableNode> c)
+    public INIConfiguration(final HierarchicalConfiguration<ImmutableNode> c)
     {
         super(c);
     }
@@ -303,7 +310,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param separator String of the new separator for INI output
      * @since 2.2
      */
-    public void setSeparatorUsedInOutput(String separator)
+    public void setSeparatorUsedInOutput(final String separator)
     {
         beginWrite(false);
         try
@@ -316,6 +323,86 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
         }
     }
 
+    /**
+     * Get separator used in INI reading. see {@code setSeparatorUsedInInput}
+     * for further explanation
+     *
+     * @return the current separator for reading the INI input
+     * @since 2.5
+     */
+    public String getSeparatorUsedInInput()
+    {
+        beginRead(false);
+        try
+        {
+            return separatorUsedInInput;
+        }
+        finally
+        {
+            endRead();
+        }
+    }
+
+    /**
+     * Allows setting the key and value separator which is used in reading
+     * an INI file
+     *
+     * @param separator String of the new separator for INI reading
+     * @since 2.5
+     */
+    public void setSeparatorUsedInInput(final String separator)
+    {
+        beginRead(false);
+        try
+        {
+            this.separatorUsedInInput = separator;
+        }
+        finally
+        {
+            endRead();
+        }
+    }
+
+    /**
+     * Get comment leading separator used in INI reading.
+     * see {@code setCommentLeadingCharsUsedInInput} for further explanation
+     *
+     * @return the current separator for reading the INI input
+     * @since 2.5
+     */
+    public String getCommentLeadingCharsUsedInInput()
+    {
+        beginRead(false);
+        try
+        {
+            return commentCharsUsedInInput;
+        }
+        finally
+        {
+            endRead();
+        }
+    }
+
+    /**
+     * Allows setting the leading comment separator which is used in reading
+     * an INI file
+     *
+     * @param separator String of the new separator for INI reading
+     * @since 2.5
+     */
+    public void setCommentLeadingCharsUsedInInput(final String separator)
+    {
+        beginRead(false);
+        try
+        {
+            this.commentCharsUsedInInput = separator;
+        }
+        finally
+        {
+            endRead();
+        }
+    }
+
     /**
      * Save the configuration to the specified writer.
      *
@@ -325,16 +412,16 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void write(Writer writer) throws ConfigurationException, IOException
+    public void write(final Writer writer) throws ConfigurationException, IOException
     {
-        PrintWriter out = new PrintWriter(writer);
+        final PrintWriter out = new PrintWriter(writer);
         boolean first = true;
         final String separator = getSeparatorUsedInOutput();
 
         beginRead(false);
         try
         {
-            for (ImmutableNode node : getModel().getNodeHandler().getRootNode()
+            for (final ImmutableNode node : getModel().getNodeHandler().getRootNode()
                     .getChildren())
             {
                 if (isSectionNode(node))
@@ -348,7 +435,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
                     out.print("]");
                     out.println();
 
-                    for (ImmutableNode child : node.getChildren())
+                    for (final ImmutableNode child : node.getChildren())
                     {
                         writeProperty(out, child.getNodeName(),
                                 child.getValue(), separator);
@@ -380,14 +467,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @throws IOException if an I/O error occurs
      */
     @Override
-    public void read(Reader in) throws ConfigurationException, IOException
+    public void read(final Reader in) throws ConfigurationException, IOException
     {
-        BufferedReader bufferedReader = new BufferedReader(in);
-        Map<String, ImmutableNode.Builder> sectionBuilders = new LinkedHashMap<>();
-        ImmutableNode.Builder rootBuilder = new ImmutableNode.Builder();
+        final BufferedReader bufferedReader = new BufferedReader(in);
+        final Map<String, ImmutableNode.Builder> sectionBuilders = new LinkedHashMap<>();
+        final ImmutableNode.Builder rootBuilder = new ImmutableNode.Builder();
 
         createNodeBuilders(bufferedReader, rootBuilder, sectionBuilders);
-        ImmutableNode rootNode = createNewRootNode(rootBuilder, sectionBuilders);
+        final ImmutableNode rootNode = createNewRootNode(rootBuilder, sectionBuilders);
         addNodes(null, rootNode.getChildren());
     }
 
@@ -400,10 +487,10 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @return the root node of the newly created hierarchy
      */
     private static ImmutableNode createNewRootNode(
-            ImmutableNode.Builder rootBuilder,
-            Map<String, ImmutableNode.Builder> sectionBuilders)
+            final ImmutableNode.Builder rootBuilder,
+            final Map<String, ImmutableNode.Builder> sectionBuilders)
     {
-        for (Map.Entry<String, ImmutableNode.Builder> e : sectionBuilders
+        for (final Map.Entry<String, ImmutableNode.Builder> e : sectionBuilders
                 .entrySet())
         {
             rootBuilder.addChild(e.getValue().name(e.getKey()).create());
@@ -421,9 +508,9 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param sectionBuilders a map storing the section builders
      * @throws IOException if an I/O error occurs
      */
-    private void createNodeBuilders(BufferedReader in,
-            ImmutableNode.Builder rootBuilder,
-            Map<String, ImmutableNode.Builder> sectionBuilders)
+    private void createNodeBuilders(final BufferedReader in,
+            final ImmutableNode.Builder rootBuilder,
+            final Map<String, ImmutableNode.Builder> sectionBuilders)
             throws IOException
     {
         ImmutableNode.Builder sectionBuilder = rootBuilder;
@@ -435,7 +522,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
             {
                 if (isSectionLine(line))
                 {
-                    String section = line.substring(1, line.length() - 1);
+                    final String section = line.substring(1, line.length() - 1);
                     sectionBuilder = sectionBuilders.get(section);
                     if (sectionBuilder == null)
                     {
@@ -448,7 +535,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
                 {
                     String key;
                     String value = "";
-                    int index = findSeparator(line);
+                    final int index = findSeparator(line);
                     if (index >= 0)
                     {
                         key = line.substring(0, index);
@@ -481,13 +568,13 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param key the key
      * @param value the value string
      */
-    private void createValueNodes(ImmutableNode.Builder sectionBuilder,
-            String key, String value)
+    private void createValueNodes(final ImmutableNode.Builder sectionBuilder,
+            final String key, final String value)
     {
-        Collection<String> values =
+        final Collection<String> values =
                 getListDelimiterHandler().split(value, false);
 
-        for (String v : values)
+        for (final String v : values)
         {
             sectionBuilder.addChild(new ImmutableNode.Builder().name(key)
                     .value(v).create());
@@ -501,7 +588,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param key the key
      * @param value the value
      */
-    private void writeProperty(PrintWriter out, String key, Object value, String separator)
+    private void writeProperty(final PrintWriter out, final String key, final Object value, final String separator)
     {
         out.print(key);
         out.print(separator);
@@ -530,27 +617,28 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param reader the reader (needed if multiple lines have to be read)
      * @throws IOException if an IO error occurs
      */
-    private static String parseValue(String val, BufferedReader reader) throws IOException
+    private String parseValue(final String val, final BufferedReader reader)
+        throws IOException
     {
-        StringBuilder propertyValue = new StringBuilder();
+        final StringBuilder propertyValue = new StringBuilder();
         boolean lineContinues;
         String value = val.trim();
 
         do
         {
-            boolean quoted = value.startsWith("\"") || value.startsWith("'");
+            final boolean quoted = value.startsWith("\"") || value.startsWith("'");
             boolean stop = false;
             boolean escape = false;
 
-            char quote = quoted ? value.charAt(0) : 0;
+            final char quote = quoted ? value.charAt(0) : 0;
 
             int i = quoted ? 1 : 0;
 
-            StringBuilder result = new StringBuilder();
+            final StringBuilder result = new StringBuilder();
             char lastChar = 0;
             while (i < value.length() && !stop)
             {
-                char c = value.charAt(i);
+                final char c = value.charAt(i);
 
                 if (quoted)
                 {
@@ -627,9 +715,9 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param line the string to check
      * @return a flag whether this line continues
      */
-    private static boolean lineContinues(String line)
+    private static boolean lineContinues(final String line)
     {
-        String s = line.trim();
+        final String s = line.trim();
         return s.equals(LINE_CONT)
                 || (s.length() > 2 && s.endsWith(LINE_CONT) && Character
                         .isWhitespace(s.charAt(s.length() - 2)));
@@ -645,7 +733,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param pos the start position
      * @return a flag whether this line continues
      */
-    private static boolean lineContinues(String line, int pos)
+    private boolean lineContinues(final String line, final int pos)
     {
         String s;
 
@@ -672,9 +760,9 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param c the character
      * @return a flag whether this character starts a comment
      */
-    private static boolean isCommentChar(char c)
+    private boolean isCommentChar(final char c)
     {
-        return COMMENT_CHARS.indexOf(c) >= 0;
+        return getCommentLeadingCharsUsedInInput().indexOf(c) >= 0;
     }
 
     /**
@@ -687,14 +775,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param line the line to be checked
      * @return the index of the separator character or -1 if none is found
      */
-    private static int findSeparator(String line)
+    private int findSeparator(final String line)
     {
         int index =
                 findSeparatorBeforeQuote(line,
                         findFirstOccurrence(line, QUOTE_CHARACTERS));
         if (index < 0)
         {
-            index = findFirstOccurrence(line, SEPARATOR_CHARS);
+            index = findFirstOccurrence(line, getSeparatorUsedInInput());
         }
         return index;
     }
@@ -708,14 +796,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @return the lowest index of a separator character or -1 if no separator
      *         is found
      */
-    private static int findFirstOccurrence(String line, String separators)
+    private static int findFirstOccurrence(final String line, final String separators)
     {
         int index = -1;
 
         for (int i = 0; i < separators.length(); i++)
         {
-            char sep = separators.charAt(i);
-            int pos = line.indexOf(sep);
+            final char sep = separators.charAt(i);
+            final int pos = line.indexOf(sep);
             if (pos >= 0)
             {
                 if (index < 0 || pos < index)
@@ -739,7 +827,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @return the index of the separator before the quote or &lt; 0 if there is
      *         none
      */
-    private static int findSeparatorBeforeQuote(String line, int quoteIndex)
+    private static int findSeparatorBeforeQuote(final String line, final int quoteIndex)
     {
         int index = quoteIndex - 1;
         while (index >= 0 && Character.isWhitespace(line.charAt(index)))
@@ -762,7 +850,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      *
      * @param value the string to be escaped
      */
-    private String escapeValue(String value)
+    private String escapeValue(final String value)
     {
         return String.valueOf(getListDelimiterHandler().escape(
                 escapeComments(value), ListDelimiterHandler.NOOP_TRANSFORMER));
@@ -774,13 +862,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param value the value to be escaped
      * @return the value with comment characters escaped
      */
-    private static String escapeComments(String value)
+    private String escapeComments(final String value)
     {
+        final String commentChars = getCommentLeadingCharsUsedInInput();
         boolean quoted = false;
 
-        for (int i = 0; i < COMMENT_CHARS.length() && !quoted; i++)
+        for (int i = 0; i < commentChars.length() && !quoted; i++)
         {
-            char c = COMMENT_CHARS.charAt(i);
+            final char c = commentChars.charAt(i);
             if (value.indexOf(c) != -1)
             {
                 quoted = true;
@@ -791,10 +880,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
         {
             return '"' + value.replaceAll("\"", "\\\\\\\"") + '"';
         }
-        else
-        {
-            return value;
-        }
+        return value;
     }
 
     /**
@@ -804,14 +890,15 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @return true if the line is empty or starts with one of the comment
      *         characters
      */
-    protected boolean isCommentLine(String line)
+    protected boolean isCommentLine(final String line)
     {
         if (line == null)
         {
             return false;
         }
         // blank lines are also treated as comment lines
-        return line.length() < 1 || COMMENT_CHARS.indexOf(line.charAt(0)) >= 0;
+        return line.length() < 1
+            || getCommentLeadingCharsUsedInInput().indexOf(line.charAt(0)) >= 0;
     }
 
     /**
@@ -820,7 +907,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param line The line to check.
      * @return true if the line contains a section
      */
-    protected boolean isSectionLine(String line)
+    protected boolean isSectionLine(final String line)
     {
         if (line == null)
         {
@@ -837,14 +924,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      */
     public Set<String> getSections()
     {
-        Set<String> sections = new LinkedHashSet<>();
+        final Set<String> sections = new LinkedHashSet<>();
         boolean globalSection = false;
         boolean inSection = false;
 
         beginRead(false);
         try
         {
-            for (ImmutableNode node : getModel().getNodeHandler().getRootNode()
+            for (final ImmutableNode node : getModel().getNodeHandler().getRootNode()
                     .getChildren())
             {
                 if (isSectionNode(node))
@@ -896,27 +983,23 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @return a configuration containing only the properties of the specified
      *         section
      */
-    public SubnodeConfiguration getSection(String name)
+    public SubnodeConfiguration getSection(final String name)
     {
         if (name == null)
         {
             return getGlobalSection();
         }
-
-        else
+        try
         {
-            try
-            {
-                return (SubnodeConfiguration) configurationAt(name, true);
-            }
-            catch (ConfigurationRuntimeException iex)
-            {
-                // the passed in key does not map to exactly one node
-                // obtain the node for the section, create it on demand
-                InMemoryNodeModel parentModel = getSubConfigurationParentModel();
-                NodeSelector selector = parentModel.trackChildNodeWithCreation(null, name, this);
-                return createSubConfigurationForTrackedNode(selector, this);
-            }
+            return (SubnodeConfiguration) configurationAt(name, true);
+        }
+        catch (final ConfigurationRuntimeException iex)
+        {
+            // the passed in key does not map to exactly one node
+            // obtain the node for the section, create it on demand
+            final InMemoryNodeModel parentModel = getSubConfigurationParentModel();
+            final NodeSelector selector = parentModel.trackChildNodeWithCreation(null, name, this);
+            return createSubConfigurationForTrackedNode(selector, this);
         }
     }
 
@@ -928,12 +1011,12 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      */
     private SubnodeConfiguration getGlobalSection()
     {
-        InMemoryNodeModel parentModel = getSubConfigurationParentModel();
-        NodeSelector selector = new NodeSelector(null); // selects parent
+        final InMemoryNodeModel parentModel = getSubConfigurationParentModel();
+        final NodeSelector selector = new NodeSelector(null); // selects parent
         parentModel.trackNode(selector, this);
-        GlobalSectionNodeModel model =
+        final GlobalSectionNodeModel model =
                 new GlobalSectionNodeModel(this, selector);
-        SubnodeConfiguration sub = new SubnodeConfiguration(this, model);
+        final SubnodeConfiguration sub = new SubnodeConfiguration(this, model);
         initSubConfigurationForThisParent(sub);
         return sub;
     }
@@ -944,7 +1027,7 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
      * @param node the node in question
      * @return a flag whether this node represents a section
      */
-    private static boolean isSectionNode(ImmutableNode node)
+    private static boolean isSectionNode(final ImmutableNode node)
     {
         return node.getValue() == null;
     }
@@ -965,8 +1048,8 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
          * @param modelSupport the underlying {@code InMemoryNodeModel}
          * @param selector the {@code NodeSelector}
          */
-        public GlobalSectionNodeModel(InMemoryNodeModelSupport modelSupport,
-                NodeSelector selector)
+        public GlobalSectionNodeModel(final InMemoryNodeModelSupport modelSupport,
+                final NodeSelector selector)
         {
             super(modelSupport, selector, true);
         }
@@ -977,43 +1060,43 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
             return new NodeHandlerDecorator<ImmutableNode>()
             {
                 @Override
-                public List<ImmutableNode> getChildren(ImmutableNode node)
+                public List<ImmutableNode> getChildren(final ImmutableNode node)
                 {
-                    List<ImmutableNode> children = super.getChildren(node);
+                    final List<ImmutableNode> children = super.getChildren(node);
                     return filterChildrenOfGlobalSection(node, children);
                 }
 
                 @Override
-                public List<ImmutableNode> getChildren(ImmutableNode node,
-                        String name)
+                public List<ImmutableNode> getChildren(final ImmutableNode node,
+                        final String name)
                 {
-                    List<ImmutableNode> children =
+                    final List<ImmutableNode> children =
                             super.getChildren(node, name);
                     return filterChildrenOfGlobalSection(node, children);
                 }
 
                 @Override
-                public int getChildrenCount(ImmutableNode node, String name)
+                public int getChildrenCount(final ImmutableNode node, final String name)
                 {
-                    List<ImmutableNode> children =
+                    final List<ImmutableNode> children =
                             (name != null) ? super.getChildren(node, name)
                                     : super.getChildren(node);
                     return filterChildrenOfGlobalSection(node, children).size();
                 }
 
                 @Override
-                public ImmutableNode getChild(ImmutableNode node, int index)
+                public ImmutableNode getChild(final ImmutableNode node, final int index)
                 {
-                    List<ImmutableNode> children = super.getChildren(node);
+                    final List<ImmutableNode> children = super.getChildren(node);
                     return filterChildrenOfGlobalSection(node, children).get(
                             index);
                 }
 
                 @Override
-                public int indexOfChild(ImmutableNode parent,
-                        ImmutableNode child)
+                public int indexOfChild(final ImmutableNode parent,
+                        final ImmutableNode child)
                 {
-                    List<ImmutableNode> children = super.getChildren(parent);
+                    final List<ImmutableNode> children = super.getChildren(parent);
                     return filterChildrenOfGlobalSection(parent, children)
                             .indexOf(child);
                 }
@@ -1035,14 +1118,14 @@ public class INIConfiguration extends BaseHierarchicalConfiguration implements
                  * @return a list with the filtered children
                  */
                 private List<ImmutableNode> filterChildrenOfGlobalSection(
-                        ImmutableNode node, List<ImmutableNode> children)
+                        final ImmutableNode node, final List<ImmutableNode> children)
                 {
                     List<ImmutableNode> filteredList;
                     if (node == getRootNode())
                     {
                         filteredList =
                                 new ArrayList<>(children.size());
-                        for (ImmutableNode child : children)
+                        for (final ImmutableNode child : children)
                         {
                             if (!isSectionNode(child))
                             {
