@@ -17,6 +17,7 @@
 package org.apache.commons.configuration2.builder.combined;
 
 import java.net.URL;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -231,10 +232,6 @@ import org.xml.sax.EntityResolver;
  * </p>
  *
  * @since 1.3
- * @author <a
- *         href="http://commons.apache.org/configuration/team-list.html">Commons
- *         Configuration team</a>
- * @version $Id: CombinedConfigurationBuilder.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<CombinedConfiguration>
 {
@@ -513,7 +510,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * the specified initialization parameters.
      * @param params a map with initialization parameters
      */
-    public CombinedConfigurationBuilder(Map<String, Object> params)
+    public CombinedConfigurationBuilder(final Map<String, Object> params)
     {
         super(CombinedConfiguration.class, params);
     }
@@ -525,7 +522,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param params a map with initialization parameters
      * @param allowFailOnInit the <em>allowFailOnInit</em> flag
      */
-    public CombinedConfigurationBuilder(Map<String, Object> params, boolean allowFailOnInit)
+    public CombinedConfigurationBuilder(final Map<String, Object> params, final boolean allowFailOnInit)
     {
         super(CombinedConfiguration.class, params, allowFailOnInit);
     }
@@ -552,7 +549,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * {@inheritDoc} This method is overridden to adapt the return type.
      */
     @Override
-    public CombinedConfigurationBuilder configure(BuilderParameters... params)
+    public CombinedConfigurationBuilder configure(final BuilderParameters... params)
     {
         super.configure(params);
         return this;
@@ -577,14 +574,14 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *         yet available or no builder with this name exists
      */
     public synchronized ConfigurationBuilder<? extends Configuration> getNamedBuilder(
-            String name) throws ConfigurationException
+            final String name) throws ConfigurationException
     {
         if (sourceData == null)
         {
             throw new ConfigurationException("Information about child builders"
                     + " has not been setup yet! Call getConfiguration() first.");
         }
-        ConfigurationBuilder<? extends Configuration> builder =
+        final ConfigurationBuilder<? extends Configuration> builder =
                 sourceData.getNamedBuilder(name);
         if (builder == null)
         {
@@ -618,10 +615,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
         {
             return Collections.emptySet();
         }
-        else
-        {
-            return Collections.unmodifiableSet(sourceData.builderNames());
-        }
+        return Collections.unmodifiableSet(sourceData.builderNames());
     }
 
     /**
@@ -661,13 +655,13 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @throws ConfigurationException if an error occurs
      */
     protected ConfigurationBuilder<? extends HierarchicalConfiguration<?>> setupDefinitionBuilder(
-            Map<String, Object> params) throws ConfigurationException
+            final Map<String, Object> params) throws ConfigurationException
     {
-        CombinedBuilderParametersImpl cbParams =
+        final CombinedBuilderParametersImpl cbParams =
                 CombinedBuilderParametersImpl.fromParameters(params);
         if (cbParams != null)
         {
-            ConfigurationBuilder<? extends HierarchicalConfiguration<?>> defBuilder =
+            final ConfigurationBuilder<? extends HierarchicalConfiguration<?>> defBuilder =
                     cbParams.getDefinitionBuilder();
             if (defBuilder != null)
             {
@@ -681,7 +675,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
             }
         }
 
-        BuilderParameters fileParams =
+        final BuilderParameters fileParams =
                 FileBasedBuilderParametersImpl.fromParameters(params);
         if (fileParams != null)
         {
@@ -704,7 +698,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @return the standard builder for the definition configuration
      */
     protected ConfigurationBuilder<? extends HierarchicalConfiguration<?>> createXMLDefinitionBuilder(
-            BuilderParameters builderParams)
+            final BuilderParameters builderParams)
     {
         return new FileBasedConfigurationBuilder<>(
                 XMLConfiguration.class).configure(builderParams);
@@ -754,11 +748,11 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * properties defined as initialization parameters.
      */
     @Override
-    protected BeanDeclaration createResultDeclaration(Map<String, Object> params)
+    protected BeanDeclaration createResultDeclaration(final Map<String, Object> params)
             throws ConfigurationException
     {
-        BeanDeclaration paramsDecl = super.createResultDeclaration(params);
-        XMLBeanDeclaration resultDecl =
+        final BeanDeclaration paramsDecl = super.createResultDeclaration(params);
+        final XMLBeanDeclaration resultDecl =
                 new XMLBeanDeclaration(getDefinitionConfiguration(),
                         KEY_RESULT, true, CombinedConfiguration.class.getName());
         return new CombinedBeanDeclaration(resultDecl, paramsDecl);
@@ -774,13 +768,13 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * </ul>
      */
     @Override
-    protected void initResultInstance(CombinedConfiguration result)
+    protected void initResultInstance(final CombinedConfiguration result)
             throws ConfigurationException
     {
         super.initResultInstance(result);
 
         currentConfiguration = result;
-        HierarchicalConfiguration<?> config = getDefinitionConfiguration();
+        final HierarchicalConfiguration<?> config = getDefinitionConfiguration();
         if (config.getMaxIndex(KEY_COMBINER) < 0)
         {
             // No combiner defined => set default
@@ -797,14 +791,27 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
         configureEntityResolver(config, currentXMLParameters);
         setUpParentInterpolator(currentConfiguration, config);
 
-        ConfigurationSourceData data = getSourceData();
-        data.createAndAddConfigurations(result, data.getOverrideSources());
+        final ConfigurationSourceData data = getSourceData();
+        final boolean createBuilders = data.getChildBuilders().isEmpty();
+        final List<ConfigurationBuilder<? extends Configuration>> overrideBuilders =
+                data.createAndAddConfigurations(result,
+                        data.getOverrideSources(), data.overrideBuilders);
+        if (createBuilders)
+        {
+            data.overrideBuilders.addAll(overrideBuilders);
+        }
         if (!data.getUnionSources().isEmpty())
         {
-            CombinedConfiguration addConfig = createAdditionalsConfiguration(result);
+            final CombinedConfiguration addConfig = createAdditionalsConfiguration(result);
             result.addConfiguration(addConfig, ADDITIONAL_NAME);
             initNodeCombinerListNodes(addConfig, config, KEY_ADDITIONAL_LIST);
-            data.createAndAddConfigurations(addConfig, data.getUnionSources());
+            final List<ConfigurationBuilder<? extends Configuration>> unionBuilders =
+                    data.createAndAddConfigurations(addConfig,
+                            data.unionDeclarations, data.unionBuilders);
+            if (createBuilders)
+            {
+                data.unionBuilders.addAll(unionBuilders);
+            }
         }
 
         result.isEmpty();  // this sets up the node structure
@@ -813,7 +820,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
 
     /**
      * Creates the {@code CombinedConfiguration} for the configuration
-     * sources in the <code>&lt;additional&gt;</code> section. This method is
+     * sources in the {@code &lt;additional&gt;} section. This method is
      * called when the builder constructs the final configuration. It creates a
      * new {@code CombinedConfiguration} and initializes some properties
      * from the result configuration.
@@ -825,9 +832,9 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @since 1.7
      */
     protected CombinedConfiguration createAdditionalsConfiguration(
-            CombinedConfiguration resultConfig)
+            final CombinedConfiguration resultConfig)
     {
-        CombinedConfiguration addConfig =
+        final CombinedConfiguration addConfig =
                 new CombinedConfiguration(new UnionCombiner());
         addConfig.setListDelimiterHandler(resultConfig.getListDelimiterHandler());
         return addConfig;
@@ -845,24 +852,24 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @throws ConfigurationException if an error occurs
      */
     protected void registerConfiguredLookups(
-            HierarchicalConfiguration<?> defConfig, Configuration resultConfig)
+            final HierarchicalConfiguration<?> defConfig, final Configuration resultConfig)
             throws ConfigurationException
     {
-        Map<String, Lookup> lookups = new HashMap<>();
+        final Map<String, Lookup> lookups = new HashMap<>();
 
-        List<? extends HierarchicalConfiguration<?>> nodes =
+        final List<? extends HierarchicalConfiguration<?>> nodes =
                 defConfig.configurationsAt(KEY_CONFIGURATION_LOOKUPS);
-        for (HierarchicalConfiguration<?> config : nodes)
+        for (final HierarchicalConfiguration<?> config : nodes)
         {
-            XMLBeanDeclaration decl = new XMLBeanDeclaration(config);
-            String key = config.getString(KEY_LOOKUP_KEY);
-            Lookup lookup = (Lookup) fetchBeanHelper().createBean(decl);
+            final XMLBeanDeclaration decl = new XMLBeanDeclaration(config);
+            final String key = config.getString(KEY_LOOKUP_KEY);
+            final Lookup lookup = (Lookup) fetchBeanHelper().createBean(decl);
             lookups.put(key, lookup);
         }
 
         if (!lookups.isEmpty())
         {
-            ConfigurationInterpolator defCI = defConfig.getInterpolator();
+            final ConfigurationInterpolator defCI = defConfig.getInterpolator();
             if (defCI != null)
             {
                 defCI.registerLookups(lookups);
@@ -881,12 +888,12 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @return the default {@code FileSystem} (may be <b>null</b>)
      * @throws ConfigurationException if an error occurs
      */
-    protected FileSystem initFileSystem(HierarchicalConfiguration<?> config)
+    protected FileSystem initFileSystem(final HierarchicalConfiguration<?> config)
             throws ConfigurationException
     {
         if (config.getMaxIndex(FILE_SYSTEM) == 0)
         {
-            XMLBeanDeclaration decl =
+            final XMLBeanDeclaration decl =
                     new XMLBeanDeclaration(config, FILE_SYSTEM);
             return (FileSystem) fetchBeanHelper().createBean(decl);
         }
@@ -903,17 +910,17 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *        <b>null</b>)
      * @throws ConfigurationException if an error occurs.
      */
-    protected void initSystemProperties(HierarchicalConfiguration<?> config,
-            String basePath) throws ConfigurationException
+    protected void initSystemProperties(final HierarchicalConfiguration<?> config,
+            final String basePath) throws ConfigurationException
     {
-        String fileName = config.getString(KEY_SYSTEM_PROPS);
+        final String fileName = config.getString(KEY_SYSTEM_PROPS);
         if (fileName != null)
         {
             try
             {
                 SystemConfiguration.setSystemProperties(basePath, fileName);
             }
-            catch (Exception ex)
+            catch (final Exception ex)
             {
                 throw new ConfigurationException(
                         "Error setting system properties from " + fileName, ex);
@@ -930,27 +937,27 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *        parameters; here the new resolver is to be stored
      * @throws ConfigurationException if an error occurs
      */
-    protected void configureEntityResolver(HierarchicalConfiguration<?> config,
-            XMLBuilderParametersImpl xmlParams) throws ConfigurationException
+    protected void configureEntityResolver(final HierarchicalConfiguration<?> config,
+            final XMLBuilderParametersImpl xmlParams) throws ConfigurationException
     {
         if (config.getMaxIndex(KEY_ENTITY_RESOLVER) == 0)
         {
-            XMLBeanDeclaration decl =
+            final XMLBeanDeclaration decl =
                     new XMLBeanDeclaration(config, KEY_ENTITY_RESOLVER, true);
-            EntityResolver resolver =
+            final EntityResolver resolver =
                     (EntityResolver) fetchBeanHelper().createBean(decl,
                             CatalogResolver.class);
-            FileSystem fileSystem = xmlParams.getFileHandler().getFileSystem();
+            final FileSystem fileSystem = xmlParams.getFileHandler().getFileSystem();
             if (fileSystem != null)
             {
                 BeanHelper.setProperty(resolver, "fileSystem", fileSystem);
             }
-            String basePath = xmlParams.getFileHandler().getBasePath();
+            final String basePath = xmlParams.getFileHandler().getBasePath();
             if (basePath != null)
             {
                 BeanHelper.setProperty(resolver, "baseDir", basePath);
             }
-            ConfigurationInterpolator ci = new ConfigurationInterpolator();
+            final ConfigurationInterpolator ci = new ConfigurationInterpolator();
             ci.registerLookups(fetchPrefixLookups());
             BeanHelper.setProperty(resolver, "interpolator", ci);
 
@@ -969,7 +976,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @return the provider that was registered for this tag or <b>null</b> if
      *         there is none
      */
-    protected ConfigurationBuilderProvider providerForTag(String tagName)
+    protected ConfigurationBuilderProvider providerForTag(final String tagName)
     {
         return currentParameters.providerForTag(tagName);
     }
@@ -985,7 +992,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *
      * @param params the parameters object to be initialized
      */
-    protected void initChildBuilderParameters(BuilderParameters params)
+    protected void initChildBuilderParameters(final BuilderParameters params)
     {
         initDefaultChildParameters(params);
 
@@ -1015,7 +1022,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param dest the destination builder object which is to be initialized
      */
     void initChildEventListeners(
-            BasicConfigurationBuilder<? extends Configuration> dest)
+            final BasicConfigurationBuilder<? extends Configuration> dest)
     {
         copyEventListeners(dest);
     }
@@ -1041,7 +1048,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param bean the bean to be initialized
      * @param decl the {@code BeanDeclaration}
      */
-    void initBean(Object bean, BeanDeclaration decl)
+    void initBean(final Object bean, final BeanDeclaration decl)
     {
         fetchBeanHelper().initBean(bean, decl);
     }
@@ -1081,13 +1088,13 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param resultConfig the result configuration
      * @param defConfig the definition configuration
      */
-    private void setUpParentInterpolator(Configuration resultConfig,
-            Configuration defConfig)
+    private void setUpParentInterpolator(final Configuration resultConfig,
+            final Configuration defConfig)
     {
         parentInterpolator = new ConfigurationInterpolator();
         parentInterpolator.addDefaultLookup(new ConfigurationLookup(
                 resultConfig));
-        ConfigurationInterpolator defInterpolator = defConfig.getInterpolator();
+        final ConfigurationInterpolator defInterpolator = defConfig.getInterpolator();
         if (defInterpolator != null)
         {
             defInterpolator.setParentInterpolator(parentInterpolator);
@@ -1111,15 +1118,16 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
         }
         else
         {
-            ConfigurationBuilder<? extends HierarchicalConfiguration<?>> defBuilder =
+            final ConfigurationBuilder<? extends HierarchicalConfiguration<?>> defBuilder =
                     getDefinitionBuilder();
             if (defBuilder instanceof FileBasedConfigurationBuilder)
             {
                 @SuppressWarnings("rawtypes")
+                final
                 FileBasedConfigurationBuilder fileBuilder =
                         (FileBasedConfigurationBuilder) defBuilder;
-                URL url = fileBuilder.getFileHandler().getURL();
-                currentXMLParameters.setBasePath((url != null) ? url
+                final URL url = fileBuilder.getFileHandler().getURL();
+                currentXMLParameters.setBasePath(url != null ? url
                         .toExternalForm() : fileBuilder.getFileHandler()
                         .getBasePath());
             }
@@ -1139,7 +1147,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @throws org.apache.commons.configuration2.ex.ConfigurationRuntimeException if an error
      *         occurs when copying properties
      */
-    private void initDefaultChildParameters(BuilderParameters params)
+    private void initDefaultChildParameters(final BuilderParameters params)
     {
         currentParameters.getChildDefaultParametersManager()
                 .initializeParameters(params);
@@ -1153,7 +1161,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *
      * @param params the parameters object
      */
-    private void initChildBasicParameters(BasicBuilderParameters params)
+    private void initChildBasicParameters(final BasicBuilderParameters params)
     {
         params.setPrefixLookups(fetchPrefixLookups());
         params.setParentInterpolator(parentInterpolator);
@@ -1171,7 +1179,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param params the parameters object
      */
     private void initChildFileBasedParameters(
-            FileBasedBuilderProperties<?> params)
+            final FileBasedBuilderProperties<?> params)
     {
         params.setBasePath(getBasePath());
         params.setFileSystem(currentXMLParameters.getFileHandler()
@@ -1184,7 +1192,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      *
      * @param params the parameters object
      */
-    private void initChildXMLParameters(XMLBuilderProperties<?> params)
+    private void initChildXMLParameters(final XMLBuilderProperties<?> params)
     {
         params.setEntityResolver(currentXMLParameters.getEntityResolver());
     }
@@ -1198,7 +1206,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param params the parameters object
      */
     private void initChildCombinedParameters(
-            CombinedBuilderParametersImpl params)
+            final CombinedBuilderParametersImpl params)
     {
         params.registerMissingProviders(currentParameters);
         params.setBasePath(getBasePath());
@@ -1238,7 +1246,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
     private ConfigurationSourceData createSourceData()
             throws ConfigurationException
     {
-        ConfigurationSourceData result = new ConfigurationSourceData();
+        final ConfigurationSourceData result = new ConfigurationSourceData();
         result.initFromDefinitionConfiguration(getDefinitionConfiguration());
         return result;
     }
@@ -1260,15 +1268,15 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param defConfig the definition configuration
      * @throws ConfigurationException if an error occurs
      */
-    private void registerConfiguredProviders(HierarchicalConfiguration<?> defConfig)
+    private void registerConfiguredProviders(final HierarchicalConfiguration<?> defConfig)
             throws ConfigurationException
     {
-        List<? extends HierarchicalConfiguration<?>> nodes =
+        final List<? extends HierarchicalConfiguration<?>> nodes =
                 defConfig.configurationsAt(KEY_CONFIGURATION_PROVIDERS);
-        for (HierarchicalConfiguration<?> config : nodes)
+        for (final HierarchicalConfiguration<?> config : nodes)
         {
-            XMLBeanDeclaration decl = new XMLBeanDeclaration(config);
-            String key = config.getString(KEY_PROVIDER_KEY);
+            final XMLBeanDeclaration decl = new XMLBeanDeclaration(config);
+            final String key = config.getString(KEY_PROVIDER_KEY);
             currentParameters.registerProvider(key,
                     (ConfigurationBuilderProvider) fetchBeanHelper().createBean(decl));
         }
@@ -1286,18 +1294,13 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
             final ConfigurationBuilder<? extends HierarchicalConfiguration<?>> defBuilder)
     {
         defBuilder.addEventListener(ConfigurationBuilderEvent.RESET,
-                new EventListener<ConfigurationBuilderEvent>()
-                {
-            @Override
-            public void onEvent(ConfigurationBuilderEvent event)
-            {
-                synchronized (CombinedConfigurationBuilder.this)
-                {
-                    reset();
-                    definitionBuilder = defBuilder;
-                }
-            }
-        });
+                event -> {
+                    synchronized (CombinedConfigurationBuilder.this)
+                    {
+                        reset();
+                        definitionBuilder = defBuilder;
+                    }
+                });
     }
 
     /**
@@ -1309,8 +1312,27 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      */
     private Map<String, ? extends Lookup> fetchPrefixLookups()
     {
-        CombinedConfiguration cc = getConfigurationUnderConstruction();
-        return (cc != null) ? cc.getInterpolator().getLookups() : null;
+        final CombinedConfiguration cc = getConfigurationUnderConstruction();
+        return cc != null ? cc.getInterpolator().getLookups() : null;
+    }
+
+    /**
+     * Creates {@code ConfigurationDeclaration} objects for the specified
+     * configurations.
+     *
+     * @param configs the list with configurations
+     * @return a collection with corresponding declarations
+     */
+    private Collection<ConfigurationDeclaration> createDeclarations(
+            final Collection<? extends HierarchicalConfiguration<?>> configs)
+    {
+        final Collection<ConfigurationDeclaration> declarations =
+                new ArrayList<>(configs.size());
+        for (final HierarchicalConfiguration<?> c : configs)
+        {
+            declarations.add(new ConfigurationDeclaration(this, c));
+        }
+        return declarations;
     }
 
     /**
@@ -1323,11 +1345,11 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      * @param defConfig the definition configuration
      * @param key the key for the list nodes
      */
-    private static void initNodeCombinerListNodes(CombinedConfiguration cc,
-            HierarchicalConfiguration<?> defConfig, String key)
+    private static void initNodeCombinerListNodes(final CombinedConfiguration cc,
+            final HierarchicalConfiguration<?> defConfig, final String key)
     {
-        List<Object> listNodes = defConfig.getList(key);
-        for (Object listNode : listNodes)
+        final List<Object> listNodes = defConfig.getList(key);
+        for (final Object listNode : listNodes)
         {
             cc.getNodeCombiner().addListNode((String) listNode);
         }
@@ -1340,7 +1362,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      */
     private static Map<String, ConfigurationBuilderProvider> createDefaultProviders()
     {
-        Map<String, ConfigurationBuilderProvider> providers =
+        final Map<String, ConfigurationBuilderProvider> providers =
                 new HashMap<>();
         for (int i = 0; i < DEFAULT_TAGS.length; i++)
         {
@@ -1360,11 +1382,17 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
      */
     private class ConfigurationSourceData
     {
-        /** A list with all builders for override configurations. */
-        private final Collection<HierarchicalConfiguration<?>> overrideBuilders;
+        /** A list with data for all builders for override configurations. */
+        private final List<ConfigurationDeclaration> overrideDeclarations;
 
-        /** A list with all builders for union configurations. */
-        private final Collection<HierarchicalConfiguration<?>> unionBuilders;
+        /** A list with data for all builders for union configurations. */
+        private final List<ConfigurationDeclaration> unionDeclarations;
+
+        /** A list with the builders for override configurations. */
+        private final List<ConfigurationBuilder<? extends Configuration>> overrideBuilders;
+
+        /** A list with the builders for union configurations. */
+        private final List<ConfigurationBuilder<? extends Configuration>> unionBuilders;
 
         /** A map for direct access to a builder by its name. */
         private final Map<String, ConfigurationBuilder<? extends Configuration>> namedBuilders;
@@ -1373,21 +1401,20 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
         private final Collection<ConfigurationBuilder<? extends Configuration>> allBuilders;
 
         /** A listener for reacting on changes of sub builders. */
-        private EventListener<ConfigurationBuilderEvent> changeListener;
+        private final EventListener<ConfigurationBuilderEvent> changeListener;
 
         /**
          * Creates a new instance of {@code ConfigurationSourceData}.
          */
         public ConfigurationSourceData()
         {
-            overrideBuilders =
-                    new LinkedList<>();
-            unionBuilders =
-                    new LinkedList<>();
-            namedBuilders =
-                    new HashMap<>();
-            allBuilders =
-                    new LinkedList<>();
+            overrideDeclarations = new ArrayList<>();
+            unionDeclarations = new ArrayList<>();
+            overrideBuilders = new ArrayList<>();
+            unionBuilders = new ArrayList<>();
+            namedBuilders = new HashMap<>();
+            allBuilders = new LinkedList<>();
+            changeListener = createBuilderChangeListener();
         }
 
         /**
@@ -1397,37 +1424,57 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          * @throws ConfigurationException if an error occurs
          */
         public void initFromDefinitionConfiguration(
-                HierarchicalConfiguration<?> config) throws ConfigurationException
+                final HierarchicalConfiguration<?> config) throws ConfigurationException
         {
-            overrideBuilders.addAll(fetchTopLevelOverrideConfigs(config));
-            overrideBuilders.addAll(config.childConfigurationsAt(KEY_OVERRIDE));
-            unionBuilders.addAll(config.childConfigurationsAt(KEY_UNION));
+            overrideDeclarations.addAll(createDeclarations(fetchTopLevelOverrideConfigs(config)));
+            overrideDeclarations.addAll(createDeclarations(config.childConfigurationsAt(KEY_OVERRIDE)));
+            unionDeclarations.addAll(createDeclarations(config.childConfigurationsAt(KEY_UNION)));
         }
 
         /**
          * Processes the declaration of configuration builder providers, creates
-         * the corresponding builder, obtains configurations, and adds them to
-         * the specified result configuration.
+         * the corresponding builder if necessary, obtains configurations, and
+         * adds them to the specified result configuration.
          *
          * @param ccResult the result configuration
          * @param srcDecl the collection with the declarations of configuration
          *        sources to process
+         * @return a list with configuration builders
          * @throws ConfigurationException if an error occurs
          */
-        public void createAndAddConfigurations(CombinedConfiguration ccResult,
-                Collection<HierarchicalConfiguration<?>> srcDecl)
+        public List<ConfigurationBuilder<? extends Configuration>> createAndAddConfigurations(
+                final CombinedConfiguration ccResult,
+                final List<ConfigurationDeclaration> srcDecl,
+                final List<ConfigurationBuilder<? extends Configuration>> builders)
                 throws ConfigurationException
         {
-            createBuilderChangeListener();
-            for (HierarchicalConfiguration<?> src : srcDecl)
+            final boolean createBuilders = builders.isEmpty();
+            List<ConfigurationBuilder<? extends Configuration>> newBuilders;
+            if (createBuilders)
             {
-                ConfigurationDeclaration decl =
-                        new ConfigurationDeclaration(
-                                CombinedConfigurationBuilder.this, src);
-                ConfigurationBuilder<? extends Configuration> builder =
-                        createConfigurationBuilder(src, decl);
-                addChildConfiguration(ccResult, decl, builder);
+                newBuilders = new ArrayList<>(srcDecl.size());
             }
+            else
+            {
+                newBuilders = builders;
+            }
+
+            for (int i = 0; i < srcDecl.size(); i++)
+            {
+                ConfigurationBuilder<? extends Configuration> b;
+                if (createBuilders)
+                {
+                    b = createConfigurationBuilder(srcDecl.get(i));
+                    newBuilders.add(b);
+                }
+                else
+                {
+                    b = builders.get(i);
+                }
+                addChildConfiguration(ccResult, srcDecl.get(i), b);
+            }
+
+            return newBuilders;
         }
 
         /**
@@ -1436,7 +1483,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          */
         public void cleanUp()
         {
-            for (ConfigurationBuilder<?> b : getChildBuilders())
+            for (final ConfigurationBuilder<?> b : getChildBuilders())
             {
                 b.removeEventListener(ConfigurationBuilderEvent.RESET,
                         changeListener);
@@ -1461,9 +1508,9 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          *
          * @return the override configuration builders
          */
-        public Collection<HierarchicalConfiguration<?>> getOverrideSources()
+        public List<ConfigurationDeclaration> getOverrideSources()
         {
-            return overrideBuilders;
+            return overrideDeclarations;
         }
 
         /**
@@ -1472,9 +1519,9 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          *
          * @return the union configuration builders
          */
-        public Collection<HierarchicalConfiguration<?>> getUnionSources()
+        public List<ConfigurationDeclaration> getUnionSources()
         {
-            return unionBuilders;
+            return unionDeclarations;
         }
 
         /**
@@ -1486,7 +1533,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          * @return the builder with this name or <b>null</b>
          */
         public ConfigurationBuilder<? extends Configuration> getNamedBuilder(
-                String name)
+                final String name)
         {
             return namedBuilders.get(name);
         }
@@ -1505,25 +1552,23 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          * Creates a configuration builder based on a source declaration in the
          * definition configuration.
          *
-         * @param src the sub configuration for the current configuration source
          * @param decl the current {@code ConfigurationDeclaration}
-         * @return the newly created bulder
+         * @return the newly created builder
          * @throws ConfigurationException if an error occurs
          */
         private ConfigurationBuilder<? extends Configuration> createConfigurationBuilder(
-                HierarchicalConfiguration<?> src, ConfigurationDeclaration decl)
-                throws ConfigurationException
+                final ConfigurationDeclaration decl) throws ConfigurationException
         {
-            ConfigurationBuilderProvider provider =
-                    providerForTag(src.getRootElementName());
+            final ConfigurationBuilderProvider provider =
+                    providerForTag(decl.getConfiguration().getRootElementName());
             if (provider == null)
             {
                 throw new ConfigurationException(
                         "Unsupported configuration source: "
-                                + src.getRootElementName());
+                                + decl.getConfiguration().getRootElementName());
             }
 
-            ConfigurationBuilder<? extends Configuration> builder =
+            final ConfigurationBuilder<? extends Configuration> builder =
                     provider.getConfigurationBuilder(decl);
             if (decl.getName() != null)
             {
@@ -1544,9 +1589,9 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          * @param builder the configuration builder
          * @throws ConfigurationException if an error occurs
          */
-        private void addChildConfiguration(CombinedConfiguration ccResult,
-                ConfigurationDeclaration decl,
-                ConfigurationBuilder<? extends Configuration> builder)
+        private void addChildConfiguration(final CombinedConfiguration ccResult,
+                final ConfigurationDeclaration decl,
+                final ConfigurationBuilder<? extends Configuration> builder)
                 throws ConfigurationException
         {
             try
@@ -1555,7 +1600,7 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
                         builder.getConfiguration(),
                         decl.getName(), decl.getAt());
             }
-            catch (ConfigurationException cex)
+            catch (final ConfigurationException cex)
             {
                 // ignore exceptions for optional configurations
                 if (!decl.isOptional())
@@ -1569,16 +1614,9 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          * Creates a listener for builder change events. This listener is
          * registered at all builders for child configurations.
          */
-        private void createBuilderChangeListener()
+        private EventListener<ConfigurationBuilderEvent> createBuilderChangeListener()
         {
-            changeListener = new EventListener<ConfigurationBuilderEvent>()
-            {
-                @Override
-                public void onEvent(ConfigurationBuilderEvent event)
-                {
-                    resetResult();
-                }
-            };
+            return event -> resetResult();
         }
 
         /**
@@ -1593,16 +1631,16 @@ public class CombinedConfigurationBuilder extends BasicConfigurationBuilder<Comb
          *         configurations
          */
         private List<? extends HierarchicalConfiguration<?>> fetchTopLevelOverrideConfigs(
-                HierarchicalConfiguration<?> config)
+                final HierarchicalConfiguration<?> config)
         {
 
-            List<? extends HierarchicalConfiguration<?>> configs =
+            final List<? extends HierarchicalConfiguration<?>> configs =
                     config.childConfigurationsAt(null);
-            for (Iterator<? extends HierarchicalConfiguration<?>> it =
+            for (final Iterator<? extends HierarchicalConfiguration<?>> it =
                     configs.iterator(); it.hasNext();)
             {
-                String nodeName = it.next().getRootElementName();
-                for (String element : CONFIG_SECTIONS)
+                final String nodeName = it.next().getRootElementName();
+                for (final String element : CONFIG_SECTIONS)
                 {
                     if (element.equals(nodeName))
                     {
