@@ -22,12 +22,13 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
 
-import org.apache.commons.lang3.text.StrLookup;
-import org.apache.commons.lang3.text.StrSubstitutor;
+import org.apache.commons.text.StringSubstitutor;
+import org.apache.commons.text.lookup.DefaultStringLookup;
 
 /**
  * <p>
@@ -39,14 +40,14 @@ import org.apache.commons.lang3.text.StrSubstitutor;
  * of this class. All interpolation tasks are delegated to this object.
  * </p>
  * <p>
- * {@code ConfigurationInterpolator} internally uses the {@code StrSubstitutor}
- * class from <a href="http://commons.apache.org/lang">Commons Lang</a>. Thus it
+ * {@code ConfigurationInterpolator} internally uses the {@code StringSubstitutor}
+ * class from <a href="https://commons.apache.org/text">Commons Text</a>. Thus it
  * supports the same syntax of variable expressions.
  * </p>
  * <p>
  * The basic idea of this class is that it can maintain a set of primitive
  * {@link Lookup} objects, each of which is identified by a special prefix. The
- * variables to be processed have the form <code>${prefix:name}</code>.
+ * variables to be processed have the form {@code ${prefix:name}}.
  * {@code ConfigurationInterpolator} will extract the prefix and determine,
  * which primitive lookup object is registered for it. Then the name of the
  * variable is passed to this object to obtain the actual value. It is also
@@ -80,11 +81,7 @@ import org.apache.commons.lang3.text.StrSubstitutor;
  * or removed at any time concurrent to interpolation operations.
  * </p>
  *
- * @version $Id: ConfigurationInterpolator.java 1790899 2017-04-10 21:56:46Z ggregory $
  * @since 1.4
- * @author <a
- *         href="http://commons.apache.org/configuration/team-list.html">Commons
- *         Configuration team</a>
  */
 public class ConfigurationInterpolator
 {
@@ -94,12 +91,35 @@ public class ConfigurationInterpolator
     /** The variable prefix. */
     private static final String VAR_START = "${";
 
+    /** The length of {@link #VAR_START}. */
+    private static final int VAR_START_LENGTH = VAR_START.length();
+
     /** The variable suffix. */
     private static final String VAR_END = "}";
 
+    /** The length of {@link #VAR_END}. */
+    private static final int VAR_END_LENGTH = VAR_END.length();
+
     /** A map containing the default prefix lookups. */
     private static final Map<String, Lookup> DEFAULT_PREFIX_LOOKUPS;
 
+    static
+    {
+        // TODO Perhaps a 3.0 version should only use Commons Text lookups.
+        // Add our own lookups.
+        final Map<String, Lookup> lookups = new HashMap<>();
+        for (final DefaultLookups lookup : DefaultLookups.values())
+        {
+            lookups.put(lookup.getPrefix(), lookup.getLookup());
+        }
+        // Add Apache Commons Text lookups but don't override existing keys.
+        for (final DefaultStringLookup lookup : DefaultStringLookup.values())
+        {
+            lookups.putIfAbsent(lookup.getKey(), new StringLookupAdapter(lookup.getStringLookup()));
+        }
+        DEFAULT_PREFIX_LOOKUPS = Collections.unmodifiableMap(lookups);
+    }
+
     /** A map with the currently registered lookup objects. */
     private final Map<String, Lookup> prefixLookups;
 
@@ -107,7 +127,7 @@ public class ConfigurationInterpolator
     private final List<Lookup> defaultLookups;
 
     /** The helper object performing variable substitution. */
-    private final StrSubstitutor substitutor;
+    private final StringSubstitutor substitutor;
 
     /** Stores a parent interpolator objects if the interpolator is nested hierarchically. */
     private volatile ConfigurationInterpolator parentInterpolator;
@@ -122,6 +142,36 @@ public class ConfigurationInterpolator
         substitutor = initSubstitutor();
     }
 
+    /**
+     * Creates a new instance based on the properties in the given specification
+     * object.
+     *
+     * @param spec the {@code InterpolatorSpecification}
+     * @return the newly created instance
+     */
+    private static ConfigurationInterpolator createInterpolator(
+            final InterpolatorSpecification spec)
+    {
+        final ConfigurationInterpolator ci = new ConfigurationInterpolator();
+        ci.addDefaultLookups(spec.getDefaultLookups());
+        ci.registerLookups(spec.getPrefixLookups());
+        ci.setParentInterpolator(spec.getParentInterpolator());
+        return ci;
+    }
+
+    /**
+     * Extracts the variable name from a value that consists of a single
+     * variable.
+     *
+     * @param strValue the value
+     * @return the extracted variable name
+     */
+    private static String extractVariableName(final String strValue)
+    {
+        return strValue.substring(VAR_START_LENGTH,
+                strValue.length() - VAR_END_LENGTH);
+    }
+
     /**
      * Creates a new {@code ConfigurationInterpolator} instance based on the
      * passed in specification object. If the {@code InterpolatorSpecification}
@@ -137,14 +187,14 @@ public class ConfigurationInterpolator
      * @since 2.0
      */
     public static ConfigurationInterpolator fromSpecification(
-            InterpolatorSpecification spec)
+            final InterpolatorSpecification spec)
     {
         if (spec == null)
         {
             throw new IllegalArgumentException(
                     "InterpolatorSpecification must not be null!");
         }
-        return (spec.getInterpolator() != null) ? spec.getInterpolator()
+        return spec.getInterpolator() != null ? spec.getInterpolator()
                 : createInterpolator(spec);
     }
 
@@ -183,6 +233,80 @@ public class ConfigurationInterpolator
         return lookup;
     }
 
+    /**
+     * Adds a default {@code Lookup} object. Default {@code Lookup} objects are
+     * queried (in the order they were added) for all variables without a
+     * special prefix. If no default {@code Lookup} objects are present, such
+     * variables won't be processed.
+     *
+     * @param defaultLookup the default {@code Lookup} object to be added (must
+     *        not be <b>null</b>)
+     * @throws IllegalArgumentException if the {@code Lookup} object is
+     *         <b>null</b>
+     */
+    public void addDefaultLookup(final Lookup defaultLookup)
+    {
+        defaultLookups.add(defaultLookup);
+    }
+
+    /**
+     * Adds all {@code Lookup} objects in the given collection as default
+     * lookups. The collection can be <b>null</b>, then this method has no
+     * effect. It must not contain <b>null</b> entries.
+     *
+     * @param lookups the {@code Lookup} objects to be added as default lookups
+     * @throws IllegalArgumentException if the collection contains a <b>null</b>
+     *         entry
+     */
+    public void addDefaultLookups(final Collection<? extends Lookup> lookups)
+    {
+        if (lookups != null)
+        {
+            defaultLookups.addAll(lookups);
+        }
+    }
+
+    /**
+     * Deregisters the {@code Lookup} object for the specified prefix at this
+     * instance. It will be removed from this instance.
+     *
+     * @param prefix the variable prefix
+     * @return a flag whether for this prefix a lookup object had been
+     *         registered
+     */
+    public boolean deregisterLookup(final String prefix)
+    {
+        return prefixLookups.remove(prefix) != null;
+    }
+
+    /**
+     * Obtains the lookup object for the specified prefix. This method is called
+     * by the {@code lookup()} method. This implementation will check
+     * whether a lookup object is registered for the given prefix. If not, a
+     * <b>null</b> lookup object will be returned (never <b>null</b>).
+     *
+     * @param prefix the prefix
+     * @return the lookup object to be used for this prefix
+     */
+    protected Lookup fetchLookupForPrefix(final String prefix)
+    {
+        return nullSafeLookup(prefixLookups.get(prefix));
+    }
+
+    /**
+     * Returns a collection with the default {@code Lookup} objects
+     * added to this {@code ConfigurationInterpolator}. These objects are not
+     * associated with a variable prefix. The returned list is a snapshot copy
+     * of the internal collection of default lookups; so manipulating it does
+     * not affect this instance.
+     *
+     * @return the default lookup objects
+     */
+    public List<Lookup> getDefaultLookups()
+    {
+        return new ArrayList<>(defaultLookups);
+    }
+
     /**
      * Returns a map with the currently registered {@code Lookup} objects and
      * their prefixes. This is a snapshot copy of the internally used map. So
@@ -196,6 +320,98 @@ public class ConfigurationInterpolator
         return new HashMap<>(prefixLookups);
     }
 
+    /**
+     * Returns the parent {@code ConfigurationInterpolator}.
+     *
+     * @return the parent {@code ConfigurationInterpolator} (can be <b>null</b>)
+     */
+    public ConfigurationInterpolator getParentInterpolator()
+    {
+        return this.parentInterpolator;
+    }
+
+    /**
+     * Creates and initializes a {@code StringSubstitutor} object which is used for
+     * variable substitution. This {@code StringSubstitutor} is assigned a
+     * specialized lookup object implementing the correct variable resolving
+     * algorithm.
+     *
+     * @return the {@code StringSubstitutor} used by this object
+     */
+    private StringSubstitutor initSubstitutor()
+    {
+        return new StringSubstitutor(key -> Objects.toString(resolve(key), null));
+    }
+
+    /**
+     * Performs interpolation of the passed in value. If the value is of type
+     * String, this method checks whether it contains variables. If so, all
+     * variables are replaced by their current values (if possible). For non
+     * string arguments, the value is returned without changes.
+     *
+     * @param value the value to be interpolated
+     * @return the interpolated value
+     */
+    public Object interpolate(final Object value)
+    {
+        if (value instanceof String)
+        {
+            final String strValue = (String) value;
+            if (looksLikeSingleVariable(strValue))
+            {
+                final Object resolvedValue = resolveSingleVariable(strValue);
+                if (resolvedValue != null && !(resolvedValue instanceof String))
+                {
+                    // If the value is again a string, it needs no special
+                    // treatment; it may also contain further variables which
+                    // must be resolved; therefore, the default mechanism is
+                    // applied.
+                    return resolvedValue;
+                }
+            }
+            return substitutor.replace(strValue);
+        }
+        return value;
+    }
+
+    /**
+     * Sets a flag that variable names can contain other variables. If enabled,
+     * variable substitution is also done in variable names.
+     *
+     * @return the substitution in variables flag
+     */
+    public boolean isEnableSubstitutionInVariables()
+    {
+        return substitutor.isEnableSubstitutionInVariables();
+    }
+
+    /**
+     * Checks whether a value to be interpolated seems to be a single variable.
+     * In this case, it is resolved directly without using the
+     * {@code StringSubstitutor}. Note that it is okay if this method returns a
+     * false positive: In this case, resolving is going to fail, and standard
+     * mechanism is used.
+     *
+     * @param strValue the value to be interpolated
+     * @return a flag whether this value seems to be a single variable
+     */
+    private boolean looksLikeSingleVariable(final String strValue)
+    {
+        return strValue.startsWith(VAR_START) && strValue.endsWith(VAR_END);
+    }
+
+    /**
+     * Returns an unmodifiable set with the prefixes, for which {@code Lookup}
+     * objects are registered at this instance. This means that variables with
+     * these prefixes can be processed.
+     *
+     * @return a set with the registered variable prefixes
+     */
+    public Set<String> prefixSet()
+    {
+        return Collections.unmodifiableSet(prefixLookups.keySet());
+    }
+
     /**
      * Registers the given {@code Lookup} object for the specified prefix at
      * this instance. From now on this lookup object will be used for variables
@@ -207,7 +423,7 @@ public class ConfigurationInterpolator
      * @throws IllegalArgumentException if either the prefix or the
      *         {@code Lookup} object is <b>null</b>
      */
-    public void registerLookup(String prefix, Lookup lookup)
+    public void registerLookup(final String prefix, final Lookup lookup)
     {
         if (prefix == null)
         {
@@ -231,7 +447,7 @@ public class ConfigurationInterpolator
      * @param lookups the map with lookups to register (may be <b>null</b>)
      * @throws IllegalArgumentException if the map contains <b>entries</b>
      */
-    public void registerLookups(Map<String, ? extends Lookup> lookups)
+    public void registerLookups(final Map<String, ? extends Lookup> lookups)
     {
         if (lookups != null)
         {
@@ -239,78 +455,6 @@ public class ConfigurationInterpolator
         }
     }
 
-    /**
-     * Deregisters the {@code Lookup} object for the specified prefix at this
-     * instance. It will be removed from this instance.
-     *
-     * @param prefix the variable prefix
-     * @return a flag whether for this prefix a lookup object had been
-     *         registered
-     */
-    public boolean deregisterLookup(String prefix)
-    {
-        return prefixLookups.remove(prefix) != null;
-    }
-
-    /**
-     * Returns an unmodifiable set with the prefixes, for which {@code Lookup}
-     * objects are registered at this instance. This means that variables with
-     * these prefixes can be processed.
-     *
-     * @return a set with the registered variable prefixes
-     */
-    public Set<String> prefixSet()
-    {
-        return Collections.unmodifiableSet(prefixLookups.keySet());
-    }
-
-    /**
-     * Returns a collection with the default {@code Lookup} objects
-     * added to this {@code ConfigurationInterpolator}. These objects are not
-     * associated with a variable prefix. The returned list is a snapshot copy
-     * of the internal collection of default lookups; so manipulating it does
-     * not affect this instance.
-     *
-     * @return the default lookup objects
-     */
-    public List<Lookup> getDefaultLookups()
-    {
-        return new ArrayList<>(defaultLookups);
-    }
-
-    /**
-     * Adds a default {@code Lookup} object. Default {@code Lookup} objects are
-     * queried (in the order they were added) for all variables without a
-     * special prefix. If no default {@code Lookup} objects are present, such
-     * variables won't be processed.
-     *
-     * @param defaultLookup the default {@code Lookup} object to be added (must
-     *        not be <b>null</b>)
-     * @throws IllegalArgumentException if the {@code Lookup} object is
-     *         <b>null</b>
-     */
-    public void addDefaultLookup(Lookup defaultLookup)
-    {
-        defaultLookups.add(defaultLookup);
-    }
-
-    /**
-     * Adds all {@code Lookup} objects in the given collection as default
-     * lookups. The collection can be <b>null</b>, then this method has no
-     * effect. It must not contain <b>null</b> entries.
-     *
-     * @param lookups the {@code Lookup} objects to be added as default lookups
-     * @throws IllegalArgumentException if the collection contains a <b>null</b>
-     *         entry
-     */
-    public void addDefaultLookups(Collection<? extends Lookup> lookups)
-    {
-        if (lookups != null)
-        {
-            defaultLookups.addAll(lookups);
-        }
-    }
-
     /**
      * Removes the specified {@code Lookup} object from the list of default
      * {@code Lookup}s.
@@ -319,89 +463,11 @@ public class ConfigurationInterpolator
      * @return a flag whether this {@code Lookup} object actually existed and
      *         was removed
      */
-    public boolean removeDefaultLookup(Lookup lookup)
+    public boolean removeDefaultLookup(final Lookup lookup)
     {
         return defaultLookups.remove(lookup);
     }
 
-    /**
-     * Sets the parent {@code ConfigurationInterpolator}. This object is used if
-     * the {@code Lookup} objects registered at this object cannot resolve a
-     * variable.
-     *
-     * @param parentInterpolator the parent {@code ConfigurationInterpolator}
-     *        object (can be <b>null</b>)
-     */
-    public void setParentInterpolator(
-            ConfigurationInterpolator parentInterpolator)
-    {
-        this.parentInterpolator = parentInterpolator;
-    }
-
-    /**
-     * Returns the parent {@code ConfigurationInterpolator}.
-     *
-     * @return the parent {@code ConfigurationInterpolator} (can be <b>null</b>)
-     */
-    public ConfigurationInterpolator getParentInterpolator()
-    {
-        return this.parentInterpolator;
-    }
-
-    /**
-     * Sets a flag that variable names can contain other variables. If enabled,
-     * variable substitution is also done in variable names.
-     *
-     * @return the substitution in variables flag
-     */
-    public boolean isEnableSubstitutionInVariables()
-    {
-        return substitutor.isEnableSubstitutionInVariables();
-    }
-
-    /**
-     * Sets the flag whether variable names can contain other variables. This
-     * flag corresponds to the {@code enableSubstitutionInVariables} property of
-     * the underlying {@code StrSubstitutor} object.
-     *
-     * @param f the new value of the flag
-     */
-    public void setEnableSubstitutionInVariables(boolean f)
-    {
-        substitutor.setEnableSubstitutionInVariables(f);
-    }
-
-    /**
-     * Performs interpolation of the passed in value. If the value is of type
-     * String, this method checks whether it contains variables. If so, all
-     * variables are replaced by their current values (if possible). For non
-     * string arguments, the value is returned without changes.
-     *
-     * @param value the value to be interpolated
-     * @return the interpolated value
-     */
-    public Object interpolate(Object value)
-    {
-        if (value instanceof String)
-        {
-            String strValue = (String) value;
-            if (looksLikeSingleVariable(strValue))
-            {
-                Object resolvedValue = resolveSingleVariable(strValue);
-                if (resolvedValue != null && !(resolvedValue instanceof String))
-                {
-                    // If the value is again a string, it needs no special
-                    // treatment; it may also contain further variables which
-                    // must be resolved; therefore, the default mechanism is
-                    // applied.
-                    return resolvedValue;
-                }
-            }
-            return substitutor.replace(strValue);
-        }
-        return value;
-    }
-
     /**
      * Resolves the specified variable. This implementation tries to extract
      * a variable prefix from the given variable name (the first colon (':') is
@@ -412,39 +478,39 @@ public class ConfigurationInterpolator
      * successful either and a parent {@code ConfigurationInterpolator} is
      * available, this object is asked to resolve the variable.
      *
-     * @param var the name of the variable whose value is to be looked up
+     * @param var the name of the variable whose value is to be looked up which may contain a prefix.
      * @return the value of this variable or <b>null</b> if it cannot be
      * resolved
      */
-    public Object resolve(String var)
+    public Object resolve(final String var)
     {
         if (var == null)
         {
             return null;
         }
 
-        int prefixPos = var.indexOf(PREFIX_SEPARATOR);
+        final int prefixPos = var.indexOf(PREFIX_SEPARATOR);
         if (prefixPos >= 0)
         {
-            String prefix = var.substring(0, prefixPos);
-            String name = var.substring(prefixPos + 1);
-            Object value = fetchLookupForPrefix(prefix).lookup(name);
+            final String prefix = var.substring(0, prefixPos);
+            final String name = var.substring(prefixPos + 1);
+            final Object value = fetchLookupForPrefix(prefix).lookup(name);
             if (value != null)
             {
                 return value;
             }
         }
 
-        for (Lookup l : defaultLookups)
+        for (final Lookup lookup : defaultLookups)
         {
-            Object value = l.lookup(var);
+            final Object value = lookup.lookup(var);
             if (value != null)
             {
                 return value;
             }
         }
 
-        ConfigurationInterpolator parent = getParentInterpolator();
+        final ConfigurationInterpolator parent = getParentInterpolator();
         if (parent != null)
         {
             return getParentInterpolator().resolve(var);
@@ -452,104 +518,40 @@ public class ConfigurationInterpolator
         return null;
     }
 
-    /**
-     * Obtains the lookup object for the specified prefix. This method is called
-     * by the {@code lookup()} method. This implementation will check
-     * whether a lookup object is registered for the given prefix. If not, a
-     * <b>null</b> lookup object will be returned (never <b>null</b>).
-     *
-     * @param prefix the prefix
-     * @return the lookup object to be used for this prefix
-     */
-    protected Lookup fetchLookupForPrefix(String prefix)
-    {
-        return nullSafeLookup(prefixLookups.get(prefix));
-    }
-
-    /**
-     * Creates and initializes a {@code StrSubstitutor} object which is used for
-     * variable substitution. This {@code StrSubstitutor} is assigned a
-     * specialized lookup object implementing the correct variable resolving
-     * algorithm.
-     *
-     * @return the {@code StrSubstitutor} used by this object
-     */
-    private StrSubstitutor initSubstitutor()
-    {
-        return new StrSubstitutor(new StrLookup<Object>()
-        {
-            @Override
-            public String lookup(String key)
-            {
-                Object result = resolve(key);
-                return (result != null) ? result.toString() : null;
-            }
-        });
-    }
-
     /**
      * Interpolates a string value that seems to be a single variable.
      *
      * @param strValue the string to be interpolated
      * @return the resolved value or <b>null</b> if resolving failed
      */
-    private Object resolveSingleVariable(String strValue)
+    private Object resolveSingleVariable(final String strValue)
     {
         return resolve(extractVariableName(strValue));
     }
 
     /**
-     * Checks whether a value to be interpolated seems to be a single variable.
-     * In this case, it is resolved directly without using the
-     * {@code StrSubstitutor}. Note that it is okay if this method returns a
-     * false positive: In this case, resolving is going to fail, and standard
-     * mechanism is used.
+     * Sets the flag whether variable names can contain other variables. This
+     * flag corresponds to the {@code enableSubstitutionInVariables} property of
+     * the underlying {@code StringSubstitutor} object.
      *
-     * @param strValue the value to be interpolated
-     * @return a flag whether this value seems to be a single variable
+     * @param f the new value of the flag
      */
-    private static boolean looksLikeSingleVariable(String strValue)
+    public void setEnableSubstitutionInVariables(final boolean f)
     {
-        return strValue.startsWith(VAR_START) && strValue.endsWith(VAR_END);
+        substitutor.setEnableSubstitutionInVariables(f);
     }
 
     /**
-     * Extracts the variable name from a value that consists of a single
+     * Sets the parent {@code ConfigurationInterpolator}. This object is used if
+     * the {@code Lookup} objects registered at this object cannot resolve a
      * variable.
      *
-     * @param strValue the value
-     * @return the extracted variable name
+     * @param parentInterpolator the parent {@code ConfigurationInterpolator}
+     *        object (can be <b>null</b>)
      */
-    private static String extractVariableName(String strValue)
+    public void setParentInterpolator(
+            final ConfigurationInterpolator parentInterpolator)
     {
-        return strValue.substring(VAR_START.length(),
-                strValue.length() - VAR_END.length());
-    }
-
-    /**
-     * Creates a new instance based on the properties in the given specification
-     * object.
-     *
-     * @param spec the {@code InterpolatorSpecification}
-     * @return the newly created instance
-     */
-    private static ConfigurationInterpolator createInterpolator(
-            InterpolatorSpecification spec)
-    {
-        ConfigurationInterpolator ci = new ConfigurationInterpolator();
-        ci.addDefaultLookups(spec.getDefaultLookups());
-        ci.registerLookups(spec.getPrefixLookups());
-        ci.setParentInterpolator(spec.getParentInterpolator());
-        return ci;
-    }
-
-    static
-    {
-        Map<String, Lookup> lookups = new HashMap<>();
-        for (DefaultLookups l : DefaultLookups.values())
-        {
-            lookups.put(l.getPrefix(), l.getLookup());
-        }
-        DEFAULT_PREFIX_LOOKUPS = Collections.unmodifiableMap(lookups);
+        this.parentInterpolator = parentInterpolator;
     }
 }
