@@ -38,11 +38,7 @@ import org.xml.sax.SAXException;
 /**
  * Thin wrapper around xml commons CatalogResolver to allow list of catalogs
  * to be provided.
- * @author <a
- * href="http://commons.apache.org/configuration/team-list.html">Commons
- * Configuration team</a>
  * @since 1.7
- * @version $Id: CatalogResolver.java 1735895 2016-03-20 18:40:47Z oheger $
  */
 public class CatalogResolver implements EntityResolver
 {
@@ -93,39 +89,39 @@ public class CatalogResolver implements EntityResolver
     }
 
     /**
-     * Set the list of catalog file names
+     * Sets the list of catalog file names
      *
      * @param catalogs The delimited list of catalog files.
      */
-    public void setCatalogFiles(String catalogs)
+    public void setCatalogFiles(final String catalogs)
     {
         manager.setCatalogFiles(catalogs);
     }
 
     /**
-     * Set the FileSystem.
+     * Sets the FileSystem.
      * @param fileSystem The FileSystem.
      */
-    public void setFileSystem(FileSystem fileSystem)
+    public void setFileSystem(final FileSystem fileSystem)
     {
         this.fs = fileSystem;
         manager.setFileSystem(fileSystem);
     }
 
     /**
-     * Set the base path.
+     * Sets the base path.
      * @param baseDir The base path String.
      */
-    public void setBaseDir(String baseDir)
+    public void setBaseDir(final String baseDir)
     {
         manager.setBaseDir(baseDir);
     }
 
     /**
-     * Set the {@code ConfigurationInterpolator}.
+     * Sets the {@code ConfigurationInterpolator}.
      * @param ci the {@code ConfigurationInterpolator}
      */
-    public void setInterpolator(ConfigurationInterpolator ci)
+    public void setInterpolator(final ConfigurationInterpolator ci)
     {
         manager.setInterpolator(ci);
     }
@@ -134,7 +130,7 @@ public class CatalogResolver implements EntityResolver
      * Enables debug logging of xml-commons Catalog processing.
      * @param debug True if debugging should be enabled, false otherwise.
      */
-    public void setDebug(boolean debug)
+    public void setDebug(final boolean debug)
     {
         if (debug)
         {
@@ -171,16 +167,17 @@ public class CatalogResolver implements EntityResolver
      * @return An InputSource for the mapped identifier, or null.
      * @throws SAXException if an error occurs.
      */
+    @SuppressWarnings("resource") // InputSource wraps an InputStream.
     @Override
-    public InputSource resolveEntity(String publicId, String systemId)
+    public InputSource resolveEntity(final String publicId, final String systemId)
             throws SAXException
     {
         String resolved = getResolver().getResolvedEntity(publicId, systemId);
 
         if (resolved != null)
         {
-            String badFilePrefix = "file://";
-            String correctFilePrefix = "file:///";
+            final String badFilePrefix = "file://";
+            final String correctFilePrefix = "file:///";
 
             // Java 5 has a bug when constructing file URLS
             if (resolved.startsWith(badFilePrefix) && !resolved.startsWith(correctFilePrefix))
@@ -190,19 +187,19 @@ public class CatalogResolver implements EntityResolver
 
             try
             {
-                URL url = locate(fs, null, resolved);
+                final URL url = locate(fs, null, resolved);
                 if (url == null)
                 {
                     throw new ConfigurationException("Could not locate "
                             + resolved);
                 }
-                InputStream is = fs.getInputStream(url);
-                InputSource iSource = new InputSource(resolved);
-                iSource.setPublicId(publicId);
-                iSource.setByteStream(is);
-                return iSource;
+                final InputStream inputStream = fs.getInputStream(url);
+                final InputSource inputSource = new InputSource(resolved);
+                inputSource.setPublicId(publicId);
+                inputSource.setByteStream(inputStream);
+                return inputSource;
             }
-            catch (Exception e)
+            catch (final Exception e)
             {
                 log.warn("Failed to create InputSource for " + resolved, e);
                 return null;
@@ -213,7 +210,7 @@ public class CatalogResolver implements EntityResolver
     }
 
     /**
-     * Returns the logger used by this configuration object.
+     * Gets the logger used by this configuration object.
      *
      * @return the logger
      */
@@ -232,7 +229,7 @@ public class CatalogResolver implements EntityResolver
      *
      * @param log the new logger
      */
-    public void setLogger(ConfigurationLogger log)
+    public void setLogger(final ConfigurationLogger log)
     {
         initLogger(log);
     }
@@ -242,9 +239,9 @@ public class CatalogResolver implements EntityResolver
      *
      * @param log the new logger
      */
-    private void initLogger(ConfigurationLogger log)
+    private void initLogger(final ConfigurationLogger log)
     {
-        this.log = (log != null) ? log : ConfigurationLogger.newDummyLogger();
+        this.log = log != null ? log : ConfigurationLogger.newDummyLogger();
     }
 
     private synchronized org.apache.xml.resolver.tools.CatalogResolver getResolver()
@@ -257,7 +254,7 @@ public class CatalogResolver implements EntityResolver
     }
 
     /**
-     * Helper method for locating a given file. This implementation delegates to
+     * Locates a given file. This implementation delegates to
      * the corresponding method in {@link FileLocatorUtils}.
      *
      * @param fs the {@code FileSystem}
@@ -265,16 +262,16 @@ public class CatalogResolver implements EntityResolver
      * @param name the file name
      * @return the URL pointing to the file
      */
-    private static URL locate(FileSystem fs, String basePath, String name)
+    private static URL locate(final FileSystem fs, final String basePath, final String name)
     {
-        FileLocator locator =
+        final FileLocator locator =
                 FileLocatorUtils.fileLocator().fileSystem(fs)
                         .basePath(basePath).fileName(name).create();
         return FileLocatorUtils.locate(locator);
     }
 
     /**
-     * Extend the CatalogManager to make the FileSystem and base directory accessible.
+     * Extends the CatalogManager to make the FileSystem and base directory accessible.
      */
     public static class CatalogManager extends org.apache.xml.resolver.CatalogManager
     {
@@ -291,16 +288,16 @@ public class CatalogResolver implements EntityResolver
         private ConfigurationInterpolator interpolator;
 
         /**
-         * Set the FileSystem
+         * Sets the FileSystem
          * @param fileSystem The FileSystem in use.
          */
-        public void setFileSystem(FileSystem fileSystem)
+        public void setFileSystem(final FileSystem fileSystem)
         {
             this.fs = fileSystem;
         }
 
         /**
-         * Retrieve the FileSystem.
+         * Gets the FileSystem.
          * @return The FileSystem.
          */
         public FileSystem getFileSystem()
@@ -309,10 +306,10 @@ public class CatalogResolver implements EntityResolver
         }
 
         /**
-         * Set the base directory.
+         * Sets the base directory.
          * @param baseDir The base directory.
          */
-        public void setBaseDir(String baseDir)
+        public void setBaseDir(final String baseDir)
         {
             if (baseDir != null)
             {
@@ -321,7 +318,7 @@ public class CatalogResolver implements EntityResolver
         }
 
         /**
-         * Return the base directory.
+         * Gets the base directory.
          * @return The base directory.
          */
         public String getBaseDir()
@@ -329,11 +326,21 @@ public class CatalogResolver implements EntityResolver
             return this.baseDir;
         }
 
-        public void setInterpolator(ConfigurationInterpolator ci)
+        /**
+         * Sets the ConfigurationInterpolator.
+         *
+         * @param configurationInterpolator the ConfigurationInterpolator.
+         */
+        public void setInterpolator(final ConfigurationInterpolator configurationInterpolator)
         {
-            interpolator = ci;
+            interpolator = configurationInterpolator;
         }
 
+        /**
+         * Gets the ConfigurationInterpolator.
+         *
+         * @return the ConfigurationInterpolator.
+         */
         public ConfigurationInterpolator getInterpolator()
         {
             return interpolator;
@@ -341,7 +348,7 @@ public class CatalogResolver implements EntityResolver
 
 
         /**
-         * Get a new catalog instance. This method is only overridden because xml-resolver
+         * Gets a new catalog instance. This method is only overridden because xml-resolver
          * might be in a parent ClassLoader and will be incapable of loading our Catalog
          * implementation.
          *
@@ -362,7 +369,7 @@ public class CatalogResolver implements EntityResolver
                     catalog.setupReaders();
                     catalog.loadSystemCatalogs();
                 }
-                catch (Exception ex)
+                catch (final Exception ex)
                 {
                     ex.printStackTrace();
                 }
@@ -377,7 +384,7 @@ public class CatalogResolver implements EntityResolver
         }
 
         /**
-         * Get a catalog instance.
+         * Gets a catalog instance.
          *
          * If this manager uses static catalogs, the same static catalog will
          * always be returned. Otherwise a new catalog will be returned.
@@ -409,47 +416,46 @@ public class CatalogResolver implements EntityResolver
         public void loadSystemCatalogs() throws IOException
         {
             fs = ((CatalogManager) catalogManager).getFileSystem();
-            String base = ((CatalogManager) catalogManager).getBaseDir();
+            final String base = ((CatalogManager) catalogManager).getBaseDir();
 
             // This is safe because the catalog manager returns a vector of strings.
-            @SuppressWarnings("unchecked")
-            Vector<String> catalogs = catalogManager.getCatalogFiles();
+            final Vector<String> catalogs = catalogManager.getCatalogFiles();
             if (catalogs != null)
             {
                 for (int count = 0; count < catalogs.size(); count++)
                 {
-                    String fileName = catalogs.elementAt(count);
+                    final String fileName = catalogs.elementAt(count);
 
                     URL url = null;
-                    InputStream is = null;
+                    InputStream inputStream = null;
 
                     try
                     {
                         url = locate(fs, base, fileName);
                         if (url != null)
                         {
-                            is = fs.getInputStream(url);
+                            inputStream = fs.getInputStream(url);
                         }
                     }
-                    catch (ConfigurationException ce)
+                    catch (final ConfigurationException ce)
                     {
-                        String name = url.toString();
+                        final String name = url.toString();
                         // Ignore the exception.
                         catalogManager.debug.message(DEBUG_ALL,
                             "Unable to get input stream for " + name + ". " + ce.getMessage());
                     }
-                    if (is != null)
+                    if (inputStream != null)
                     {
-                        String mimeType = fileNameMap.getContentTypeFor(fileName);
+                        final String mimeType = fileNameMap.getContentTypeFor(fileName);
                         try
                         {
                             if (mimeType != null)
                             {
-                                parseCatalog(mimeType, is);
+                                parseCatalog(mimeType, inputStream);
                                 continue;
                             }
                         }
-                        catch (Exception ex)
+                        catch (final Exception ex)
                         {
                             // Ignore the exception.
                             catalogManager.debug.message(DEBUG_ALL,
@@ -458,7 +464,7 @@ public class CatalogResolver implements EntityResolver
                         }
                         finally
                         {
-                            is.close();
+                            inputStream.close();
                         }
                     }
                     parseCatalog(base, fileName);
@@ -468,12 +474,12 @@ public class CatalogResolver implements EntityResolver
         }
 
         /**
-         * Parse the specified catalog file.
+         * Parses the specified catalog file.
          * @param baseDir The base directory, if not included in the file name.
          * @param fileName The catalog file. May be a full URI String.
          * @throws IOException If an error occurs.
          */
-        public void parseCatalog(String baseDir, String fileName) throws IOException
+        public void parseCatalog(final String baseDir, final String fileName) throws IOException
         {
             base = locate(fs, baseDir, fileName);
             catalogCwd = base;
@@ -484,14 +490,14 @@ public class CatalogResolver implements EntityResolver
 
             for (int count = 0; !parsed && count < readerArr.size(); count++)
             {
-                CatalogReader reader = (CatalogReader) readerArr.get(count);
-                InputStream inStream;
+                final CatalogReader reader = (CatalogReader) readerArr.get(count);
+                InputStream inputStream;
 
                 try
                 {
-                    inStream = fs.getInputStream(base);
+                    inputStream = fs.getInputStream(base);
                 }
-                catch (Exception ex)
+                catch (final Exception ex)
                 {
                     catalogManager.debug.message(DEBUG_NORMAL, "Unable to access " + base
                         + ex.getMessage());
@@ -500,10 +506,10 @@ public class CatalogResolver implements EntityResolver
 
                 try
                 {
-                    reader.readCatalog(this, inStream);
+                    reader.readCatalog(this, inputStream);
                     parsed = true;
                 }
-                catch (CatalogException ce)
+                catch (final CatalogException ce)
                 {
                     catalogManager.debug.message(DEBUG_NORMAL, "Parse failed for " + fileName
                             + ce.getMessage());
@@ -511,22 +517,19 @@ public class CatalogResolver implements EntityResolver
                     {
                         break;
                     }
-                    else
-                    {
-                        // try again!
-                        continue;
-                    }
+                    // try again!
+                    continue;
                 }
                 finally
                 {
                     try
                     {
-                        inStream.close();
+                        inputStream.close();
                     }
-                    catch (IOException ioe)
+                    catch (final IOException ioe)
                     {
                         // Ignore the exception.
-                        inStream = null;
+                        inputStream = null;
                     }
                 }
             }
@@ -538,16 +541,16 @@ public class CatalogResolver implements EntityResolver
         }
 
         /**
-         * Perform character normalization on a URI reference.
+         * Performs character normalization on a URI reference.
          *
          * @param uriref The URI reference
          * @return The normalized URI reference.
          */
         @Override
-        protected String normalizeURI(String uriref)
+        protected String normalizeURI(final String uriref)
         {
-            ConfigurationInterpolator ci = ((CatalogManager) catalogManager).getInterpolator();
-            String resolved = (ci != null) ? String.valueOf(ci.interpolate(uriref)) : uriref;
+            final ConfigurationInterpolator ci = ((CatalogManager) catalogManager).getInterpolator();
+            final String resolved = ci != null ? String.valueOf(ci.interpolate(uriref)) : uriref;
             return super.normalizeURI(resolved);
         }
     }
