@@ -38,7 +38,7 @@ import org.apache.commons.lang3.StringUtils;
  * delimiter, which is by the default a dot (&quot;.&quot;).</li>
  * <li>Navigating from a node to one of its attributes using the attribute node
  * delimiter, which by default follows the XPATH like syntax
- * <code>[@&lt;attributeName&gt;]</code>.</li>
+ * {@code [@&lt;attributeName&gt;]}.</li>
  * <li>If there are multiple child or attribute nodes with the same name, a
  * specific node can be selected using a numerical index. By default indices are
  * written in parenthesis.</li>
@@ -108,10 +108,6 @@ import org.apache.commons.lang3.StringUtils;
  * </p>
  *
  * @since 1.3
- * @author <a
- * href="http://commons.apache.org/configuration/team-list.html">Commons
- * Configuration team</a>
- * @version $Id: DefaultExpressionEngine.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class DefaultExpressionEngine implements ExpressionEngine
 {
@@ -136,7 +132,7 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param syms the object with the symbols (must not be <b>null</b>)
      * @throws IllegalArgumentException if the symbols are <b>null</b>
      */
-    public DefaultExpressionEngine(DefaultExpressionEngineSymbols syms)
+    public DefaultExpressionEngine(final DefaultExpressionEngineSymbols syms)
     {
         this(syms, null);
     }
@@ -152,8 +148,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
      *        then a default matcher is used
      * @throws IllegalArgumentException if the symbols are <b>null</b>
      */
-    public DefaultExpressionEngine(DefaultExpressionEngineSymbols syms,
-            NodeMatcher<String> nodeNameMatcher)
+    public DefaultExpressionEngine(final DefaultExpressionEngineSymbols syms,
+            final NodeMatcher<String> nodeNameMatcher)
     {
         if (syms == null)
         {
@@ -162,7 +158,7 @@ public class DefaultExpressionEngine implements ExpressionEngine
 
         symbols = syms;
         nameMatcher =
-                (nodeNameMatcher != null) ? nodeNameMatcher
+                nodeNameMatcher != null ? nodeNameMatcher
                         : NodeNameMatchers.EQUALS;
     }
 
@@ -183,10 +179,10 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * comment.
      */
     @Override
-    public <T> List<QueryResult<T>> query(T root, String key,
-            NodeHandler<T> handler)
+    public <T> List<QueryResult<T>> query(final T root, final String key,
+            final NodeHandler<T> handler)
     {
-        List<QueryResult<T>> results = new LinkedList<>();
+        final List<QueryResult<T>> results = new LinkedList<>();
         findNodesForKey(new DefaultConfigurationKey(this, key).iterator(),
                 root, results, handler);
         return results;
@@ -200,27 +196,23 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * returned.
      */
     @Override
-    public <T> String nodeKey(T node, String parentKey, NodeHandler<T> handler)
+    public <T> String nodeKey(final T node, final String parentKey, final NodeHandler<T> handler)
     {
         if (parentKey == null)
         {
             // this is the root node
             return StringUtils.EMPTY;
         }
-
-        else
-        {
-            DefaultConfigurationKey key = new DefaultConfigurationKey(this,
-                    parentKey);
-                key.append(handler.nodeName(node), true);
-            return key.toString();
-        }
+        final DefaultConfigurationKey key = new DefaultConfigurationKey(this,
+                parentKey);
+            key.append(handler.nodeName(node), true);
+        return key.toString();
     }
 
     @Override
-    public String attributeKey(String parentKey, String attributeName)
+    public String attributeKey(final String parentKey, final String attributeName)
     {
-        DefaultConfigurationKey key =
+        final DefaultConfigurationKey key =
                 new DefaultConfigurationKey(this, parentKey);
         key.appendAttribute(attributeName);
         return key.toString();
@@ -234,12 +226,12 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * name of the current node with its index is returned.
      */
     @Override
-    public <T> String canonicalKey(T node, String parentKey,
-            NodeHandler<T> handler)
+    public <T> String canonicalKey(final T node, final String parentKey,
+            final NodeHandler<T> handler)
     {
-        String nodeName = handler.nodeName(node);
-        T parent = handler.getParent(node);
-        DefaultConfigurationKey key =
+        final String nodeName = handler.nodeName(node);
+        final T parent = handler.getParent(node);
+        final DefaultConfigurationKey key =
                 new DefaultConfigurationKey(this, parentKey);
         key.append(StringUtils.defaultString(nodeName));
 
@@ -333,9 +325,9 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @return a data object with information needed for the add operation
      */
     @Override
-    public <T> NodeAddData<T> prepareAdd(T root, String key, NodeHandler<T> handler)
+    public <T> NodeAddData<T> prepareAdd(final T root, final String key, final NodeHandler<T> handler)
     {
-        DefaultConfigurationKey.KeyIterator it = new DefaultConfigurationKey(
+        final DefaultConfigurationKey.KeyIterator it = new DefaultConfigurationKey(
                 this, key).iterator();
         if (!it.hasNext())
         {
@@ -343,8 +335,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
                     "Key for add operation must be defined!");
         }
 
-        T parent = findLastPathNode(it, root, handler);
-        List<String> pathNodes = new LinkedList<>();
+        final T parent = findLastPathNode(it, root, handler);
+        final List<String> pathNodes = new LinkedList<>();
 
         while (it.hasNext())
         {
@@ -374,8 +366,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param handler the node handler
      */
     protected <T> void findNodesForKey(
-            DefaultConfigurationKey.KeyIterator keyPart, T node,
-            Collection<QueryResult<T>> results, NodeHandler<T> handler)
+            final DefaultConfigurationKey.KeyIterator keyPart, final T node,
+            final Collection<QueryResult<T>> results, final NodeHandler<T> handler)
     {
         if (!keyPart.hasNext())
         {
@@ -384,7 +376,7 @@ public class DefaultExpressionEngine implements ExpressionEngine
 
         else
         {
-            String key = keyPart.nextKey(false);
+            final String key = keyPart.nextKey(false);
             if (keyPart.isPropertyKey())
             {
                 processSubNodes(keyPart, findChildNodesByName(handler, node, key),
@@ -411,10 +403,10 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param handler the node handler
      * @return the last existing node on the given path
      */
-    protected <T> T findLastPathNode(DefaultConfigurationKey.KeyIterator keyIt,
-            T node, NodeHandler<T> handler)
+    protected <T> T findLastPathNode(final DefaultConfigurationKey.KeyIterator keyIt,
+            final T node, final NodeHandler<T> handler)
     {
-        String keyPart = keyIt.nextKey(false);
+        final String keyPart = keyIt.nextKey(false);
 
         if (keyIt.hasNext())
         {
@@ -425,7 +417,7 @@ public class DefaultExpressionEngine implements ExpressionEngine
                         "Invalid path for add operation: "
                                 + "Attribute key in the middle!");
             }
-            int idx =
+            final int idx =
                     keyIt.hasIndex() ? keyIt.getIndex() : handler
                             .getMatchingChildrenCount(node, nameMatcher,
                                     keyPart) - 1;
@@ -435,18 +427,11 @@ public class DefaultExpressionEngine implements ExpressionEngine
             {
                 return node;
             }
-            else
-            {
-                return findLastPathNode(keyIt,
-                        findChildNodesByName(handler, node, keyPart).get(idx),
-                        handler);
-            }
-        }
-
-        else
-        {
-            return node;
+            return findLastPathNode(keyIt,
+                    findChildNodesByName(handler, node, keyPart).get(idx),
+                    handler);
         }
+        return node;
     }
 
     /**
@@ -460,8 +445,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param nodes the target collection
      * @param handler the node handler
      */
-    private <T> void processSubNodes(DefaultConfigurationKey.KeyIterator keyPart,
-            List<T> subNodes, Collection<QueryResult<T>> nodes, NodeHandler<T> handler)
+    private <T> void processSubNodes(final DefaultConfigurationKey.KeyIterator keyPart,
+            final List<T> subNodes, final Collection<QueryResult<T>> nodes, final NodeHandler<T> handler)
     {
         if (keyPart.hasIndex())
         {
@@ -473,7 +458,7 @@ public class DefaultExpressionEngine implements ExpressionEngine
         }
         else
         {
-            for (T node : subNodes)
+            for (final T node : subNodes)
             {
                 findNodesForKey((DefaultConfigurationKey.KeyIterator) keyPart
                         .clone(), node, nodes, handler);
@@ -491,8 +476,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param <T> the type of the nodes to be dealt with
      * @return the index of this node
      */
-    private <T> int determineIndex(T node, T parent, String nodeName,
-                                          NodeHandler<T> handler)
+    private <T> int determineIndex(final T node, final T parent, final String nodeName,
+                                          final NodeHandler<T> handler)
     {
         return findChildNodesByName(handler, parent, nodeName).indexOf(node);
     }
@@ -508,8 +493,8 @@ public class DefaultExpressionEngine implements ExpressionEngine
      * @param <T> the type of the nodes to be dealt with
      * @return a list with all matching child nodes
      */
-    private <T> List<T> findChildNodesByName(NodeHandler<T> handler, T parent,
-            String nodeName)
+    private <T> List<T> findChildNodesByName(final NodeHandler<T> handler, final T parent,
+            final String nodeName)
     {
         return handler.getMatchingChildren(parent, nameMatcher, nodeName);
     }
