@@ -36,7 +36,6 @@ import org.xml.sax.InputSource;
 /**
  * Test class for HierarchicalConfigurationXMLReader.
  *
- * @version $Id: TestHierarchicalConfigurationXMLReader.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestHierarchicalConfigurationXMLReader
 {
@@ -48,8 +47,8 @@ public class TestHierarchicalConfigurationXMLReader
     @Before
     public void setUp() throws Exception
     {
-        XMLConfiguration config = new XMLConfiguration();
-        FileHandler handler = new FileHandler(config);
+        final XMLConfiguration config = new XMLConfiguration();
+        final FileHandler handler = new FileHandler(config);
         handler.load(TEST_FILE);
         parser = new HierarchicalConfigurationXMLReader<>(config);
     }
@@ -57,12 +56,12 @@ public class TestHierarchicalConfigurationXMLReader
     @Test
     public void testParse() throws Exception
     {
-        SAXSource source = new SAXSource(parser, new InputSource());
-        DOMResult result = new DOMResult();
-        Transformer trans = TransformerFactory.newInstance().newTransformer();
+        final SAXSource source = new SAXSource(parser, new InputSource());
+        final DOMResult result = new DOMResult();
+        final Transformer trans = TransformerFactory.newInstance().newTransformer();
         trans.transform(source, result);
-        Node root = ((Document) result.getNode()).getDocumentElement();
-        JXPathContext ctx = JXPathContext.newContext(root);
+        final Node root = ((Document) result.getNode()).getDocumentElement();
+        final JXPathContext ctx = JXPathContext.newContext(root);
 
         assertEquals("Wrong name of root element", "database", root.getNodeName());
         assertEquals("Wrong number of children of root", 1, ctx.selectNodes(
