@@ -23,7 +23,6 @@ import java.util.List;
  * A simple bean class used for testing bean creation operations that has
  * a list of children of a different bean type.
  *
- * @version $Id: BeanCreationTestBeanWithListChild.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class BeanCreationTestBeanWithListChild
 {
@@ -38,7 +37,7 @@ public class BeanCreationTestBeanWithListChild
         return children;
     }
 
-    public void setChildren(List<BeanCreationTestBean> buddies)
+    public void setChildren(final List<BeanCreationTestBean> buddies)
     {
         this.children.clear();
         this.children.addAll(buddies);
@@ -49,7 +48,7 @@ public class BeanCreationTestBeanWithListChild
         return intValue;
     }
 
-    public void setIntValue(int intValue)
+    public void setIntValue(final int intValue)
     {
         this.intValue = intValue;
     }
@@ -59,7 +58,7 @@ public class BeanCreationTestBeanWithListChild
         return stringValue;
     }
 
-    public void setStringValue(String stringValue)
+    public void setStringValue(final String stringValue)
     {
         this.stringValue = stringValue;
     }
