@@ -19,7 +19,6 @@ package org.apache.commons.configuration2.beanutils;
 /**
  * Another test bean class for bean creation operations which defines some constructors.
  *
- * @version $Id: BeanCreationTestCtorBean.java 1624601 2014-09-12 18:04:36Z oheger $
  */
 public class BeanCreationTestCtorBean extends BeanCreationTestBean
 {
@@ -27,17 +26,17 @@ public class BeanCreationTestCtorBean extends BeanCreationTestBean
     {
     }
 
-    public BeanCreationTestCtorBean(BeanCreationTestBean buddy)
+    public BeanCreationTestCtorBean(final BeanCreationTestBean buddy)
     {
         setBuddy(buddy);
     }
 
-    public BeanCreationTestCtorBean(String s)
+    public BeanCreationTestCtorBean(final String s)
     {
         setStringValue(s);
     }
 
-    public BeanCreationTestCtorBean(String s, int i)
+    public BeanCreationTestCtorBean(final String s, final int i)
     {
         this(s);
         setIntValue(i);
