@@ -22,6 +22,7 @@ import static org.junit.Assert.assertSame;
 
 import java.util.Map;
 
+import org.apache.commons.configuration2.ConfigurationConsumer;
 import org.apache.commons.configuration2.PropertiesConfiguration;
 import org.apache.commons.configuration2.PropertiesConfigurationLayout;
 import org.apache.commons.configuration2.beanutils.BeanHelper;
@@ -33,7 +34,6 @@ import org.junit.Test;
 /**
  * Test class for {@code PropertiesBuilderParametersImpl}.
  *
- * @version $Id: TestPropertiesBuilderParametersImpl.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestPropertiesBuilderParametersImpl
 {
@@ -63,20 +63,34 @@ public class TestPropertiesBuilderParametersImpl
     @Test
     public void testSetLayout()
     {
-        PropertiesConfigurationLayout layout =
+        final PropertiesConfigurationLayout layout =
                 new PropertiesConfigurationLayout();
         assertSame("Wrong result", params, params.setLayout(layout));
         assertSame("Layout not set", layout,
                 params.getParameters().get("layout"));
     }
 
+    /**
+     * Tests whether the include listener can be set.
+     */
+    @Test
+    public void testSetIncludeListener()
+    {
+        final ConfigurationConsumer<ConfigurationException> includeListener =
+                EasyMock.createMock(ConfigurationConsumer.class);
+        EasyMock.replay(includeListener);
+        assertSame("Wrong result", params, params.setIncludeListener(includeListener));
+        assertSame("IncludeListener not set", includeListener,
+                params.getParameters().get("includeListener"));
+    }
+
     /**
      * Tests whether the IO factory can be set.
      */
     @Test
     public void testSetIOFactory()
     {
-        PropertiesConfiguration.IOFactory factory =
+        final PropertiesConfiguration.IOFactory factory =
                 EasyMock.createMock(PropertiesConfiguration.IOFactory.class);
         EasyMock.replay(factory);
         assertSame("Wrong result", params, params.setIOFactory(factory));
@@ -90,7 +104,7 @@ public class TestPropertiesBuilderParametersImpl
     @Test
     public void testBeanPropertiesAccess() throws Exception
     {
-        PropertiesConfiguration.IOFactory factory =
+        final PropertiesConfiguration.IOFactory factory =
                 EasyMock.createMock(PropertiesConfiguration.IOFactory.class);
         EasyMock.replay(factory);
         BeanHelper.setProperty(params, "IOFactory", factory);
@@ -99,7 +113,7 @@ public class TestPropertiesBuilderParametersImpl
         BeanHelper.setProperty(params, "fileName", "test.properties");
         assertEquals("Wrong file name", "test.properties", params
                 .getFileHandler().getFileName());
-        Map<String, Object> paramsMap = params.getParameters();
+        final Map<String, Object> paramsMap = params.getParameters();
         assertEquals("Wrong exception flag", Boolean.TRUE,
                 paramsMap.get("throwExceptionOnMissing"));
         assertSame("Factory not set", factory,
@@ -112,18 +126,23 @@ public class TestPropertiesBuilderParametersImpl
     @Test
     public void testInheritFrom()
     {
-        PropertiesConfiguration.IOFactory factory =
+        final PropertiesConfiguration.IOFactory factory =
                 EasyMock.createMock(PropertiesConfiguration.IOFactory.class);
-        params.setIOFactory(factory).setIncludesAllowed(false)
-                .setLayout(new PropertiesConfigurationLayout());
-        params.setThrowExceptionOnMissing(true);
-        PropertiesBuilderParametersImpl params2 =
+        final ConfigurationConsumer<ConfigurationException> includeListener =
+                EasyMock.createMock(ConfigurationConsumer.class);
+        params.setIOFactory(factory)
+                .setIncludeListener(includeListener)
+                .setIncludesAllowed(false)
+                .setLayout(new PropertiesConfigurationLayout())
+                .setThrowExceptionOnMissing(true);
+        final PropertiesBuilderParametersImpl params2 =
                 new PropertiesBuilderParametersImpl();
 
         params2.inheritFrom(params.getParameters());
-        Map<String, Object> parameters = params2.getParameters();
+        final Map<String, Object> parameters = params2.getParameters();
         assertEquals("Exception flag not set", Boolean.TRUE,
                 parameters.get("throwExceptionOnMissing"));
+        assertEquals("IncludeListener not set", includeListener, parameters.get("includeListener"));
         assertEquals("IOFactory not set", factory, parameters.get("IOFactory"));
         assertEquals("Include flag not set", Boolean.FALSE,
                 parameters.get("includesAllowed"));
@@ -137,14 +156,31 @@ public class TestPropertiesBuilderParametersImpl
     @Test
     public void testSetIOFactoryProperty() throws ConfigurationException
     {
-        PropertiesConfiguration.IOFactory factory =
+        final PropertiesConfiguration.IOFactory factory =
                 new PropertiesConfiguration.DefaultIOFactory();
-        ConfigurationBuilder<PropertiesConfiguration> builder =
+        final ConfigurationBuilder<PropertiesConfiguration> builder =
                 new FileBasedConfigurationBuilder<>(
                         PropertiesConfiguration.class)
                 .configure(params.setIOFactory(factory));
 
-        PropertiesConfiguration config = builder.getConfiguration();
+        final PropertiesConfiguration config = builder.getConfiguration();
         assertEquals("Wrong IO factory", factory, config.getIOFactory());
     }
+
+    /**
+     * Tests whether the IncludeListener property can be correctly set.
+     */
+    @Test
+    public void testSetIncludeListenerProperty() throws ConfigurationException
+    {
+        final ConfigurationConsumer<ConfigurationException> includeListener =
+                PropertiesConfiguration.DEFAULT_INCLUDE_LISTENER;
+        final ConfigurationBuilder<PropertiesConfiguration> builder =
+                new FileBasedConfigurationBuilder<>(
+                        PropertiesConfiguration.class)
+                .configure(params.setIncludeListener(includeListener));
+
+        final PropertiesConfiguration config = builder.getConfiguration();
+        assertEquals("Wrong IncludeListener", includeListener, config.getIncludeListener());
+    }
 }
