@@ -42,7 +42,6 @@ import org.apache.commons.configuration2.ex.ConfigurationException;
 import org.apache.commons.configuration2.io.FileHandler;
 import org.apache.commons.configuration2.reloading.AlwaysReloadingDetector;
 import org.apache.commons.configuration2.reloading.RandomReloadingDetector;
-import org.apache.commons.configuration2.reloading.ReloadingDetector;
 import org.apache.commons.configuration2.sync.ReadWriteSynchronizer;
 import org.apache.commons.configuration2.sync.Synchronizer;
 import org.apache.commons.configuration2.tree.MergeCombiner;
@@ -56,7 +55,6 @@ import org.junit.rules.TemporaryFolder;
  * Test class for {@code ReloadingCombinedConfigurationBuilder} which actually
  * accesses files to be reloaded.
  *
- * @version $Id: TestReloadingCombinedConfigurationBuilderFileBased.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestReloadingCombinedConfigurationBuilderFileBased
 {
@@ -94,7 +92,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @param config the definition configuration
      * @param fileName the name of the file
      */
-    private static void addReloadSource(Configuration config, String fileName)
+    private static void addReloadSource(final Configuration config, final String fileName)
     {
         config.addProperty(PROP_SRC + "(-1)[@fileName]", fileName);
         config.addProperty(PROP_SRC + "[@config-reload]", Boolean.TRUE);
@@ -107,7 +105,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @param content the file's content
      * @throws IOException if an error occurs
      */
-    private static void writeFile(File file, String content) throws IOException
+    private static void writeFile(final File file, final String content) throws IOException
     {
         PrintWriter out = null;
         try
@@ -131,12 +129,12 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      *
      * @param f the file to be written or <b>null</b> for creating a new one
      * @param content the content of the file
-     * @return the <code>File</code> object for the test file
+     * @return the {@code File} object for the test file
      * @throws IOException if an error occurs
      */
-    private File writeReloadFile(File f, String content) throws IOException
+    private File writeReloadFile(final File f, final String content) throws IOException
     {
-        File file = (f != null) ? f : folder.newFile();
+        final File file = f != null ? f : folder.newFile();
         writeFile(file, content);
         return file;
     }
@@ -150,7 +148,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @return the file that was written
      * @throws IOException if an error occurs
      */
-    private File writeReloadFile(File f, int tagIdx, int value)
+    private File writeReloadFile(final File f, final int tagIdx, final int value)
             throws IOException
     {
         return writeReloadFile(f,
@@ -163,7 +161,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @param idx the index of the property
      * @return the test property with this index
      */
-    private static String testProperty(int idx)
+    private static String testProperty(final int idx)
     {
         return PROP_RELOAD + idx;
     }
@@ -174,21 +172,11 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     @Test
     public void testReloadFromFile() throws ConfigurationException, IOException
     {
-        File xmlConf1 = writeReloadFile(null, 1, 0);
-        File xmlConf2 = writeReloadFile(null, 2, 0);
-        ReloadingDetectorFactory detectorFactory =
-                new ReloadingDetectorFactory()
-                {
-                    @Override
-                    public ReloadingDetector createReloadingDetector(
-                            FileHandler handler,
-                            FileBasedBuilderParametersImpl params)
-                            throws ConfigurationException
-                    {
-                        return new AlwaysReloadingDetector();
-                    }
-                };
-        BaseHierarchicalConfiguration defConf = new BaseHierarchicalConfiguration();
+        final File xmlConf1 = writeReloadFile(null, 1, 0);
+        final File xmlConf2 = writeReloadFile(null, 2, 0);
+        final ReloadingDetectorFactory detectorFactory =
+                (handler, params) -> new AlwaysReloadingDetector();
+        final BaseHierarchicalConfiguration defConf = new BaseHierarchicalConfiguration();
         addReloadSource(defConf, xmlConf1.getAbsolutePath());
         addReloadSource(defConf, xmlConf2.getAbsolutePath());
         builder.configure(parameters
@@ -230,26 +218,16 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     {
         final int threadCount = 4;
         final int loopCount = 100;
-        ReloadingDetectorFactory detectorFactory =
-                new ReloadingDetectorFactory()
-                {
-                    @Override
-                    public ReloadingDetector createReloadingDetector(
-                            FileHandler handler,
-                            FileBasedBuilderParametersImpl params)
-                            throws ConfigurationException
-                    {
-                        return new RandomReloadingDetector();
-                    }
-                };
-        BaseHierarchicalConfiguration defConf = new BaseHierarchicalConfiguration();
+        final ReloadingDetectorFactory detectorFactory =
+                (handler, params) -> new RandomReloadingDetector();
+        final BaseHierarchicalConfiguration defConf = new BaseHierarchicalConfiguration();
         defConf.addProperty("header.result.nodeCombiner[@config-class]",
                 MergeCombiner.class.getName());
         defConf.addProperty("header.result.expressionEngine[@config-class]",
                 XPathExpressionEngine.class.getName());
         addReloadSource(defConf, "configA.xml");
         addReloadSource(defConf, "configB.xml");
-        Synchronizer sync = new ReadWriteSynchronizer();
+        final Synchronizer sync = new ReadWriteSynchronizer();
         builder.configure(parameters
                 .combined()
                 .setDefinitionBuilder(new ConstantConfigurationBuilder(defConf))
@@ -268,8 +246,8 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
         assertEquals("Wrong initial value", "100", builder.getConfiguration()
                 .getString("/property[@name='config']/@value"));
 
-        Thread testThreads[] = new Thread[threadCount];
-        int failures[] = new int[threadCount];
+        final Thread testThreads[] = new Thread[threadCount];
+        final int failures[] = new int[threadCount];
 
         for (int i = 0; i < testThreads.length; ++i)
         {
@@ -296,11 +274,11 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @throws ConfigurationException if a configuration-related error occurs
      * @throws InterruptedException if waiting is interrupted
      */
-    private void checkReloadDefinitionFile(File defFile) throws IOException,
+    private void checkReloadDefinitionFile(final File defFile) throws IOException,
             ConfigurationException, InterruptedException
     {
-        File src1 = writeReloadFile(null, 1, 0);
-        File src2 = writeReloadFile(null, 1, 1);
+        final File src1 = writeReloadFile(null, 1, 0);
+        final File src2 = writeReloadFile(null, 1, 1);
         writeDefinitionFile(defFile, src1);
         CombinedConfiguration config = builder.getConfiguration();
         assertEquals("Wrong initial value", 0, config.getInt(testProperty(1)));
@@ -330,7 +308,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     public void testReloadDefinitionFileExplicitBuilder()
             throws ConfigurationException, IOException, InterruptedException
     {
-        File defFile = folder.newFile();
+        final File defFile = folder.newFile();
         builder.configure(parameters.combined().setDefinitionBuilder(
                 new ReloadingFileBasedConfigurationBuilder<>(
                         XMLConfiguration.class).configure(parameters.xml()
@@ -346,7 +324,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     public void testReloadDefinitionFileDefaultBuilder()
             throws ConfigurationException, IOException, InterruptedException
     {
-        File defFile = folder.newFile();
+        final File defFile = folder.newFile();
         builder.configure(parameters.combined().setDefinitionBuilderParameters(
                 parameters.xml().setReloadingRefreshDelay(0L).setFile(defFile)));
         checkReloadDefinitionFile(defFile);
@@ -360,10 +338,10 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
      * @param src the configuration source file to be referenced
      * @throws ConfigurationException if an error occurs
      */
-    private void writeDefinitionFile(File defFile, File src)
+    private void writeDefinitionFile(final File defFile, final File src)
             throws ConfigurationException
     {
-        XMLConfiguration defConf = new XMLConfiguration();
+        final XMLConfiguration defConf = new XMLConfiguration();
         addReloadSource(defConf, src.getAbsolutePath());
         new FileHandler(defConf).save(defFile);
     }
@@ -376,7 +354,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     {
         private final BaseHierarchicalConfiguration configuration;
 
-        public ConstantConfigurationBuilder(BaseHierarchicalConfiguration conf)
+        public ConstantConfigurationBuilder(final BaseHierarchicalConfiguration conf)
         {
             super(BaseHierarchicalConfiguration.class);
             configuration = conf;
@@ -407,8 +385,8 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
         /** The number of test operations. */
         private final int count;
 
-        ReloadThread(ReloadingCombinedConfigurationBuilder bldr,
-                int[] failures, int index, int count)
+        ReloadThread(final ReloadingCombinedConfigurationBuilder bldr,
+                final int[] failures, final int index, final int count)
         {
             builder = bldr;
             this.failures = failures;
@@ -425,7 +403,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
                 try
                 {
                     builder.getReloadingController().checkForReloading(null);
-                    String value =
+                    final String value =
                             builder.getConfiguration().getString(
                                     "/property[@name='config']/@value");
                     if (value == null || !value.equals("100"))
@@ -433,7 +411,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
                         ++failures[index];
                     }
                 }
-                catch (Exception ex)
+                catch (final Exception ex)
                 {
                     ++failures[index];
                 }
