@@ -22,6 +22,7 @@ import static org.junit.Assert.assertSame;
 
 import java.io.File;
 import java.net.URL;
+import java.util.Map;
 
 import org.apache.commons.configuration2.CombinedConfiguration;
 import org.apache.commons.configuration2.Configuration;
@@ -29,16 +30,17 @@ import org.apache.commons.configuration2.ConfigurationAssert;
 import org.apache.commons.configuration2.INIConfiguration;
 import org.apache.commons.configuration2.PropertiesConfiguration;
 import org.apache.commons.configuration2.XMLConfiguration;
+import org.apache.commons.configuration2.builder.BasicConfigurationBuilder;
 import org.apache.commons.configuration2.builder.FileBasedConfigurationBuilder;
 import org.apache.commons.configuration2.builder.combined.CombinedConfigurationBuilder;
 import org.apache.commons.configuration2.ex.ConfigurationException;
 import org.apache.commons.configuration2.plist.PropertyListConfiguration;
+import org.junit.Assert;
 import org.junit.Test;
 
 /**
  * Test class for {@code Configurations}.
  *
- * @version $Id: TestConfigurations.java 1624601 2014-09-12 18:04:36Z oheger $
  */
 public class TestConfigurations
 {
@@ -58,12 +60,12 @@ public class TestConfigurations
     private static final String TEST_PLIST = "test.plist";
 
     /**
-     * Generates a full path for the test file with the given name.
+     * Generates an absolute path for the test file with the given name.
      *
      * @param name the name of the test file
      * @return the full path to this file
      */
-    private static String filePath(String name)
+    private static String absolutePath(final String name)
     {
         return ConfigurationAssert.getTestFile(name).getAbsolutePath();
     }
@@ -75,7 +77,7 @@ public class TestConfigurations
     @Test
     public void testDefaultParameters()
     {
-        Configurations configs = new Configurations();
+        final Configurations configs = new Configurations();
         assertNotNull("No parameters", configs.getParameters());
     }
 
@@ -85,8 +87,8 @@ public class TestConfigurations
     @Test
     public void testInitWithParameters()
     {
-        Parameters params = new Parameters();
-        Configurations configs = new Configurations(params);
+        final Parameters params = new Parameters();
+        final Configurations configs = new Configurations(params);
         assertSame("Wrong parameters", params, configs.getParameters());
     }
 
@@ -97,9 +99,9 @@ public class TestConfigurations
     @Test
     public void testFileBasedBuilderWithFile()
     {
-        Configurations configs = new Configurations();
-        File file = ConfigurationAssert.getTestFile(TEST_PROPERTIES);
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final File file = ConfigurationAssert.getTestFile(TEST_PROPERTIES);
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
                 configs.fileBasedBuilder(PropertiesConfiguration.class, file);
         assertEquals("Wrong file", file.toURI(), builder.getFileHandler()
                 .getFile().toURI());
@@ -112,9 +114,9 @@ public class TestConfigurations
     @Test
     public void testFileBasedBuilderWithURL()
     {
-        Configurations configs = new Configurations();
-        URL url = ConfigurationAssert.getTestURL("test.properties");
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final URL url = ConfigurationAssert.getTestURL("test.properties");
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
                 configs.fileBasedBuilder(PropertiesConfiguration.class, url);
         assertEquals("Wrong URL", url, builder.getFileHandler().getURL());
     }
@@ -126,9 +128,9 @@ public class TestConfigurations
     @Test
     public void testFileBasedBuilderWithPath()
     {
-        Configurations configs = new Configurations();
-        String filePath = filePath(TEST_PROPERTIES);
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final String filePath = absolutePath(TEST_PROPERTIES);
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
                 configs.fileBasedBuilder(PropertiesConfiguration.class,
                         filePath);
         assertEquals("Wrong path", filePath, builder.getFileHandler()
@@ -140,7 +142,7 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkPList(Configuration config)
+    private static void checkPList(final Configuration config)
     {
         assertEquals("string1", config.getProperty("simple-string"));
     }
@@ -151,8 +153,8 @@ public class TestConfigurations
     @Test
     public void testFileBasedFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertyListConfiguration config =
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config =
                 configs.fileBased(PropertyListConfiguration.class,
                         ConfigurationAssert.getTestFile(TEST_PLIST));
         checkPList(config);
@@ -164,8 +166,8 @@ public class TestConfigurations
     @Test
     public void testFileBasedURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertyListConfiguration config =
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config =
                 configs.fileBased(PropertyListConfiguration.class,
                         ConfigurationAssert.getTestURL(TEST_PLIST));
         checkPList(config);
@@ -177,10 +179,10 @@ public class TestConfigurations
     @Test
     public void testFileBasedPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertyListConfiguration config =
+        final Configurations configs = new Configurations();
+        final PropertyListConfiguration config =
                 configs.fileBased(PropertyListConfiguration.class,
-                        filePath(TEST_PLIST));
+                        absolutePath(TEST_PLIST));
         checkPList(config);
     }
 
@@ -189,7 +191,7 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkProperties(Configuration config)
+    private static void checkProperties(final Configuration config)
     {
         assertEquals("true", config.getString("configuration.loaded"));
     }
@@ -201,8 +203,8 @@ public class TestConfigurations
     @Test
     public void testPropertiesBuilderFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
                 configs.propertiesBuilder(ConfigurationAssert
                         .getTestFile(TEST_PROPERTIES));
         checkProperties(builder.getConfiguration());
@@ -214,8 +216,8 @@ public class TestConfigurations
     @Test
     public void testPropertiesFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertiesConfiguration config =
+        final Configurations configs = new Configurations();
+        final PropertiesConfiguration config =
                 configs.properties(ConfigurationAssert
                         .getTestFile(TEST_PROPERTIES));
         checkProperties(config);
@@ -228,8 +230,8 @@ public class TestConfigurations
     @Test
     public void testPropertiesBuilderFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
                 configs.propertiesBuilder(ConfigurationAssert
                         .getTestURL(TEST_PROPERTIES));
         checkProperties(builder.getConfiguration());
@@ -241,8 +243,8 @@ public class TestConfigurations
     @Test
     public void testPropertiesFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertiesConfiguration config =
+        final Configurations configs = new Configurations();
+        final PropertiesConfiguration config =
                 configs.properties(ConfigurationAssert
                         .getTestURL(TEST_PROPERTIES));
         checkProperties(config);
@@ -255,21 +257,99 @@ public class TestConfigurations
     @Test
     public void testPropertiesBuilderFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
-                configs.propertiesBuilder(filePath(TEST_PROPERTIES));
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+                configs.propertiesBuilder(absolutePath(TEST_PROPERTIES));
         checkProperties(builder.getConfiguration());
     }
 
+    /**
+     * Tests whether a builder for a properties configuration can be created for
+     * a given file path when an include is not found.
+     */
+    @Test
+    public void testPropertiesBuilderFromPathIncludeNotFoundFail() throws ConfigurationException
+    {
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builder =
+                configs.propertiesBuilder(absolutePath("include-not-found.properties"));
+        try
+        {
+            builder.getConfiguration();
+            Assert.fail("Expected ConfigurationException");
+        }
+        catch (ConfigurationException e) {
+            // ignore
+        }
+    }
+
+    /**
+     * Tests whether a builder for a properties configuration can be created for
+     * a given file path when an include is not found.
+     */
+    @Test
+    public void testPropertiesBuilderFromPathIncludeNotFoundPass() throws ConfigurationException
+    {
+        final Configurations configs = new Configurations();
+        final String absPath = absolutePath("include-not-found.properties");
+        final FileBasedConfigurationBuilder<PropertiesConfiguration> builderFail =
+                configs.propertiesBuilder(absPath);
+        // Expect failure:
+        try
+        {
+            builderFail.getConfiguration();
+            Assert.fail("Expected ConfigurationException");
+        }
+        catch (ConfigurationException e)
+        {
+            // Ignore
+            // e.printStackTrace();
+        }
+        // Expect failure:
+        try
+        {
+            configs.properties(absPath);
+        }
+        catch (ConfigurationException e) {
+            // Ignore
+            // e.printStackTrace();
+        }
+        {
+            // Expect success:
+            // @formatter:off
+            final Map<String, Object> map =
+                    new Parameters().properties()
+                            .setPath(absPath)
+                            .setIncludeListener(PropertiesConfiguration.NOOP_INCLUDE_LISTENER)
+                            .getParameters();
+            // @formatter:on
+            final BasicConfigurationBuilder<PropertiesConfiguration> builderOk = configs.propertiesBuilder(absPath)
+                    .addParameters(map);
+            final PropertiesConfiguration configuration = builderOk.getConfiguration();
+            assertEquals("valueA", configuration.getString("keyA"));
+        }
+        {
+            // Expect success:
+            // @formatter:off
+            final BasicConfigurationBuilder<PropertiesConfiguration> builderOk = configs.propertiesBuilder(
+                    new Parameters().properties()
+                        .setPath(absPath)
+                        .setIncludeListener(PropertiesConfiguration.NOOP_INCLUDE_LISTENER));
+            // @formatter:on
+            final PropertiesConfiguration configuration = builderOk.getConfiguration();
+            assertEquals("valueA", configuration.getString("keyA"));
+        }
+    }
+
     /**
      * Tests whether a properties configuration can be loaded from a file path.
      */
     @Test
     public void testPropertiesFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        PropertiesConfiguration config =
-                configs.properties(filePath(TEST_PROPERTIES));
+        final Configurations configs = new Configurations();
+        final PropertiesConfiguration config =
+                configs.properties(absolutePath(TEST_PROPERTIES));
         checkProperties(config);
     }
 
@@ -278,7 +358,7 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkXML(Configuration config)
+    private static void checkXML(final Configuration config)
     {
         assertEquals("value", config.getProperty("element"));
     }
@@ -290,8 +370,8 @@ public class TestConfigurations
     @Test
     public void testXMLBuilderFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<XMLConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
                 configs.xmlBuilder(ConfigurationAssert.getTestFile(TEST_XML));
         checkXML(builder.getConfiguration());
     }
@@ -302,8 +382,8 @@ public class TestConfigurations
     @Test
     public void testXMLFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        XMLConfiguration config =
+        final Configurations configs = new Configurations();
+        final XMLConfiguration config =
                 configs.xml(ConfigurationAssert.getTestFile(TEST_XML));
         checkXML(config);
     }
@@ -315,8 +395,8 @@ public class TestConfigurations
     @Test
     public void testXMLBuilderFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<XMLConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
                 configs.xmlBuilder(ConfigurationAssert.getTestURL(TEST_XML));
         checkXML(builder.getConfiguration());
     }
@@ -327,8 +407,8 @@ public class TestConfigurations
     @Test
     public void testXMLFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        XMLConfiguration config =
+        final Configurations configs = new Configurations();
+        final XMLConfiguration config =
                 configs.xml(ConfigurationAssert.getTestURL(TEST_XML));
         checkXML(config);
     }
@@ -340,9 +420,9 @@ public class TestConfigurations
     @Test
     public void testXMLBuilderFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<XMLConfiguration> builder =
-                configs.xmlBuilder(filePath(TEST_XML));
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<XMLConfiguration> builder =
+                configs.xmlBuilder(absolutePath(TEST_XML));
         checkXML(builder.getConfiguration());
     }
 
@@ -352,8 +432,8 @@ public class TestConfigurations
     @Test
     public void testXMLFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        XMLConfiguration config = configs.xml(filePath(TEST_XML));
+        final Configurations configs = new Configurations();
+        final XMLConfiguration config = configs.xml(absolutePath(TEST_XML));
         checkXML(config);
     }
 
@@ -362,7 +442,7 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkINI(INIConfiguration config)
+    private static void checkINI(final INIConfiguration config)
     {
         assertEquals("yes", config.getProperty("testini.loaded"));
     }
@@ -374,8 +454,8 @@ public class TestConfigurations
     @Test
     public void testINIBuilderFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<INIConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder =
                 configs.iniBuilder(ConfigurationAssert.getTestFile(TEST_INI));
         checkINI(builder.getConfiguration());
     }
@@ -386,8 +466,8 @@ public class TestConfigurations
     @Test
     public void testINIFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        INIConfiguration config =
+        final Configurations configs = new Configurations();
+        final INIConfiguration config =
                 configs.ini(ConfigurationAssert.getTestFile(TEST_INI));
         checkINI(config);
     }
@@ -399,8 +479,8 @@ public class TestConfigurations
     @Test
     public void testINIBuilderFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<INIConfiguration> builder =
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder =
                 configs.iniBuilder(ConfigurationAssert.getTestURL(TEST_INI));
         checkINI(builder.getConfiguration());
     }
@@ -411,8 +491,8 @@ public class TestConfigurations
     @Test
     public void testINIFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        INIConfiguration config =
+        final Configurations configs = new Configurations();
+        final INIConfiguration config =
                 configs.ini(ConfigurationAssert.getTestURL(TEST_INI));
         checkINI(config);
     }
@@ -424,9 +504,9 @@ public class TestConfigurations
     @Test
     public void testINIBuilderFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        FileBasedConfigurationBuilder<INIConfiguration> builder =
-                configs.iniBuilder(filePath(TEST_INI));
+        final Configurations configs = new Configurations();
+        final FileBasedConfigurationBuilder<INIConfiguration> builder =
+                configs.iniBuilder(absolutePath(TEST_INI));
         checkINI(builder.getConfiguration());
     }
 
@@ -436,8 +516,8 @@ public class TestConfigurations
     @Test
     public void testINIFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        INIConfiguration config = configs.ini(filePath(TEST_INI));
+        final Configurations configs = new Configurations();
+        final INIConfiguration config = configs.ini(absolutePath(TEST_INI));
         checkINI(config);
     }
 
@@ -446,7 +526,7 @@ public class TestConfigurations
      *
      * @param config the configuration instance to be checked.
      */
-    private static void checkCombined(Configuration config)
+    private static void checkCombined(final Configuration config)
     {
         checkProperties(config);
         checkXML(config);
@@ -459,8 +539,8 @@ public class TestConfigurations
     @Test
     public void testCombinedBuilderFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfigurationBuilder builder =
+        final Configurations configs = new Configurations();
+        final CombinedConfigurationBuilder builder =
                 configs.combinedBuilder(ConfigurationAssert
                         .getTestFile(TEST_COMBINED));
         checkCombined(builder.getConfiguration());
@@ -472,8 +552,8 @@ public class TestConfigurations
     @Test
     public void testCombinedFromFile() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfiguration config =
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config =
                 configs.combined(ConfigurationAssert.getTestFile(TEST_COMBINED));
         checkCombined(config);
     }
@@ -485,8 +565,8 @@ public class TestConfigurations
     @Test
     public void testCombinedBuilderFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfigurationBuilder builder =
+        final Configurations configs = new Configurations();
+        final CombinedConfigurationBuilder builder =
                 configs.combinedBuilder(ConfigurationAssert
                         .getTestURL(TEST_COMBINED));
         checkCombined(builder.getConfiguration());
@@ -498,8 +578,8 @@ public class TestConfigurations
     @Test
     public void testCombinedFromURL() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfiguration config =
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config =
                 configs.combined(ConfigurationAssert.getTestURL(TEST_COMBINED));
         checkCombined(config);
     }
@@ -511,9 +591,9 @@ public class TestConfigurations
     @Test
     public void testCombinedBuilderFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfigurationBuilder builder =
-                configs.combinedBuilder(filePath(TEST_COMBINED));
+        final Configurations configs = new Configurations();
+        final CombinedConfigurationBuilder builder =
+                configs.combinedBuilder(absolutePath(TEST_COMBINED));
         checkCombined(builder.getConfiguration());
     }
 
@@ -523,9 +603,9 @@ public class TestConfigurations
     @Test
     public void testCombinedFromPath() throws ConfigurationException
     {
-        Configurations configs = new Configurations();
-        CombinedConfiguration config =
-                configs.combined(filePath(TEST_COMBINED));
+        final Configurations configs = new Configurations();
+        final CombinedConfiguration config =
+                configs.combined(absolutePath(TEST_COMBINED));
         checkCombined(config);
     }
 }
