@@ -24,7 +24,6 @@ import org.junit.Test;
 /**
  * Test class for {@code EventType}.
  *
- * @version $Id: TestEventType.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestEventType
 {
@@ -43,7 +42,7 @@ public class TestEventType
     @Test
     public void testToString()
     {
-        String s = eventType.toString();
+        final String s = eventType.toString();
         assertEquals("Wrong string", "EventType [ TEST ]", s);
     }
 }
