@@ -31,7 +31,6 @@ import org.junit.Test;
 /**
  * Test class for {@code CombinedReloadingController}.
  *
- * @version $Id: TestCombinedReloadingController.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestCombinedReloadingController
 {
@@ -74,10 +73,10 @@ public class TestCombinedReloadingController
     private CombinedReloadingController setUpController()
     {
         initSubControllers();
-        List<ReloadingController> lstCtrls =
+        final List<ReloadingController> lstCtrls =
                 new ArrayList<>(
                         Arrays.asList(subControllers));
-        CombinedReloadingController result =
+        final CombinedReloadingController result =
                 new CombinedReloadingController(lstCtrls);
         // check whether a defensive copy is created
         lstCtrls.clear();
@@ -100,7 +99,7 @@ public class TestCombinedReloadingController
     public void testInitNullEntries()
     {
         initSubControllers();
-        Collection<ReloadingController> ctrls =
+        final Collection<ReloadingController> ctrls =
                 new ArrayList<>(
                         Arrays.asList(subControllers));
         ctrls.add(null);
@@ -113,11 +112,13 @@ public class TestCombinedReloadingController
     @Test
     public void testCheckForReloadingTrue()
     {
-        CombinedReloadingController ctrl = setUpController();
+        final CombinedReloadingController ctrl = setUpController();
         EasyMock.expect(subControllers[0].checkForReloading(null)).andReturn(
                 Boolean.FALSE);
         EasyMock.expect(subControllers[1].checkForReloading(null)).andReturn(
                 Boolean.TRUE);
+        EasyMock.expect(subControllers[2].checkForReloading(null)).andReturn(
+                Boolean.FALSE);
         replaySubControllers();
         assertTrue("Wrong result", ctrl.checkForReloading("someData"));
         verifySubSontrollers();
@@ -129,8 +130,8 @@ public class TestCombinedReloadingController
     @Test
     public void testCheckForReloadingFalse()
     {
-        CombinedReloadingController ctrl = setUpController();
-        for (ReloadingController rc : subControllers)
+        final CombinedReloadingController ctrl = setUpController();
+        for (final ReloadingController rc : subControllers)
         {
             EasyMock.expect(rc.checkForReloading(null))
                     .andReturn(Boolean.FALSE);
@@ -146,10 +147,14 @@ public class TestCombinedReloadingController
     @Test
     public void testResetReloadingState()
     {
-        CombinedReloadingController ctrl = setUpController();
+        final CombinedReloadingController ctrl = setUpController();
         EasyMock.expect(subControllers[0].checkForReloading(null)).andReturn(
                 Boolean.TRUE);
-        for (ReloadingController rc : subControllers)
+        EasyMock.expect(subControllers[1].checkForReloading(null)).andReturn(
+                Boolean.FALSE);
+        EasyMock.expect(subControllers[2].checkForReloading(null)).andReturn(
+                Boolean.FALSE);
+        for (final ReloadingController rc : subControllers)
         {
             rc.resetReloadingState();
         }
@@ -166,8 +171,8 @@ public class TestCombinedReloadingController
     @Test
     public void testResetInitialReloadingState()
     {
-        CombinedReloadingController ctrl = setUpController();
-        for (ReloadingController rc : subControllers)
+        final CombinedReloadingController ctrl = setUpController();
+        for (final ReloadingController rc : subControllers)
         {
             rc.resetReloadingState();
         }
@@ -182,9 +187,9 @@ public class TestCombinedReloadingController
     @Test
     public void testGetSubControllers()
     {
-        CombinedReloadingController ctrl = setUpController();
+        final CombinedReloadingController ctrl = setUpController();
         replaySubControllers();
-        Collection<ReloadingController> subs = ctrl.getSubControllers();
+        final Collection<ReloadingController> subs = ctrl.getSubControllers();
         assertEquals("Wrong number of sub controllers", subControllers.length,
                 subs.size());
         assertTrue("Wrong sub controllers",
@@ -197,7 +202,7 @@ public class TestCombinedReloadingController
     @Test(expected = UnsupportedOperationException.class)
     public void testGetSubControllersModify()
     {
-        Collection<ReloadingController> subs =
+        final Collection<ReloadingController> subs =
                 setUpController().getSubControllers();
         subs.clear();
     }
