@@ -26,14 +26,12 @@ import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.lang3.mutable.MutableObject;
 import org.easymock.EasyMock;
-import org.easymock.IAnswer;
 import org.junit.Before;
 import org.junit.Test;
 
 /**
  * Test class for {@code PeriodicReloadingTrigger}.
  *
- * @version $Id: TestPeriodicReloadingTrigger.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestPeriodicReloadingTrigger
 {
@@ -76,7 +74,7 @@ public class TestPeriodicReloadingTrigger
     @Test
     public void testDefaultExecutor()
     {
-        PeriodicReloadingTrigger trigger =
+        final PeriodicReloadingTrigger trigger =
                 new PeriodicReloadingTrigger(controller, CTRL_PARAM, PERIOD, UNIT);
         assertNotNull("No executor service", trigger.getExecutorService());
     }
@@ -107,6 +105,7 @@ public class TestPeriodicReloadingTrigger
     private static ScheduledFuture<Void> createFutureMock()
     {
         @SuppressWarnings("unchecked")
+        final
         ScheduledFuture<Void> mock = EasyMock.createMock(ScheduledFuture.class);
         return mock;
     }
@@ -117,7 +116,7 @@ public class TestPeriodicReloadingTrigger
      *
      * @param future the future object to return
      */
-    private void expectSchedule(ScheduledFuture<Void> future)
+    private void expectSchedule(final ScheduledFuture<Void> future)
     {
         executor.scheduleAtFixedRate(EasyMock.anyObject(Runnable.class),
                 EasyMock.eq(PERIOD), EasyMock.eq(PERIOD), EasyMock.eq(UNIT));
@@ -137,20 +136,15 @@ public class TestPeriodicReloadingTrigger
         final MutableObject<Runnable> refTask = new MutableObject<>();
         expectSchedule(null);
         EasyMock.expectLastCall().andAnswer(
-                new IAnswer<ScheduledFuture<Void>>()
-                {
-                    @Override
-                    public ScheduledFuture<Void> answer() throws Throwable
-                    {
-                        refTask.setValue((Runnable) EasyMock
-                                .getCurrentArguments()[0]);
-                        return future;
-                    }
+                () -> {
+                    refTask.setValue((Runnable) EasyMock
+                            .getCurrentArguments()[0]);
+                    return future;
                 });
         EasyMock.expect(controller.checkForReloading(CTRL_PARAM)).andReturn(
                 Boolean.FALSE);
         EasyMock.replay(future, controller, executor);
-        PeriodicReloadingTrigger trigger = createTrigger();
+        final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         assertTrue("Not started", trigger.isRunning());
         refTask.getValue().run();
@@ -163,10 +157,10 @@ public class TestPeriodicReloadingTrigger
     @Test
     public void testStartTwice()
     {
-        ScheduledFuture<Void> future = createFutureMock();
+        final ScheduledFuture<Void> future = createFutureMock();
         expectSchedule(future);
         EasyMock.replay(future, controller, executor);
-        PeriodicReloadingTrigger trigger = createTrigger();
+        final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.start();
         EasyMock.verify(future, controller, executor);
@@ -188,11 +182,11 @@ public class TestPeriodicReloadingTrigger
     @Test
     public void testStop()
     {
-        ScheduledFuture<Void> future = createFutureMock();
+        final ScheduledFuture<Void> future = createFutureMock();
         expectSchedule(future);
         EasyMock.expect(future.cancel(false)).andReturn(Boolean.TRUE);
         EasyMock.replay(future, controller, executor);
-        PeriodicReloadingTrigger trigger = createTrigger();
+        final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.stop();
         assertFalse("Still running", trigger.isRunning());
@@ -205,12 +199,12 @@ public class TestPeriodicReloadingTrigger
     @Test
     public void testShutdown()
     {
-        ScheduledFuture<Void> future = createFutureMock();
+        final ScheduledFuture<Void> future = createFutureMock();
         expectSchedule(future);
         EasyMock.expect(future.cancel(false)).andReturn(Boolean.TRUE);
         executor.shutdown();
         EasyMock.replay(future, controller, executor);
-        PeriodicReloadingTrigger trigger = createTrigger();
+        final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.shutdown();
         EasyMock.verify(future, controller, executor);
