@@ -29,7 +29,6 @@ import org.junit.Test;
 /**
  * Test class for NodeAddData.
  *
- * @version $Id: TestNodeAddData.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestNodeAddData
 {
@@ -54,7 +53,7 @@ public class TestNodeAddData
     @Test
     public void testPathNodesNull()
     {
-        NodeAddData<ImmutableNode> data =
+        final NodeAddData<ImmutableNode> data =
                 new NodeAddData<>(parentNode, TEST_NODENAME,
                         false, null);
         assertTrue("Got path nodes", data.getPathNodes().isEmpty());
@@ -67,7 +66,7 @@ public class TestNodeAddData
     @Test(expected = UnsupportedOperationException.class)
     public void testPathNodesNullModify()
     {
-        NodeAddData<ImmutableNode> data =
+        final NodeAddData<ImmutableNode> data =
                 new NodeAddData<>(parentNode, TEST_NODENAME,
                         false, null);
         data.getPathNodes().add("test");
@@ -80,9 +79,9 @@ public class TestNodeAddData
     @Test
     public void testInitPathNodesDefensiveCopy()
     {
-        List<String> pathNodes = new ArrayList<>();
+        final List<String> pathNodes = new ArrayList<>();
         pathNodes.add(PATH_NODE_NAME);
-        NodeAddData<ImmutableNode> data =
+        final NodeAddData<ImmutableNode> data =
                 new NodeAddData<>(parentNode, TEST_NODENAME,
                         false, pathNodes);
         pathNodes.add("anotherNode");
@@ -99,7 +98,7 @@ public class TestNodeAddData
     @Test(expected = UnsupportedOperationException.class)
     public void testPathNodesDefinedModify()
     {
-        NodeAddData<ImmutableNode> data =
+        final NodeAddData<ImmutableNode> data =
                 new NodeAddData<>(parentNode, TEST_NODENAME,
                         false, Collections.singleton(PATH_NODE_NAME));
         data.getPathNodes().add("anotherNode");
