@@ -19,7 +19,6 @@ package org.apache.commons.configuration2.tree;
 /**
  * Test class for {@code TreeData}
  *
- * @version $Id: TestTreeData.java 1624601 2014-09-12 18:04:36Z oheger $
  */
 public class TestTreeData extends AbstractImmutableNodeHandlerTest
 {
@@ -28,9 +27,9 @@ public class TestTreeData extends AbstractImmutableNodeHandlerTest
      * with the given root node.
      */
     @Override
-    protected NodeHandler<ImmutableNode> createHandler(ImmutableNode root)
+    protected NodeHandler<ImmutableNode> createHandler(final ImmutableNode root)
     {
-        InMemoryNodeModel model = new InMemoryNodeModel(root);
+        final InMemoryNodeModel model = new InMemoryNodeModel(root);
         return model.getTreeData();
     }
 }
